@@ -21,12 +21,12 @@
 #include "moc_variable_test.cpp"
 
 #include <kateglobal.h>
-#include <ktexteditor/editor.h>
 #include <ktexteditor/document.h>
+#include <ktexteditor/editor.h>
 #include <ktexteditor/view.h>
 
-#include <QtTest>
 #include <QUuid>
+#include <QtTest>
 
 using namespace KTextEditor;
 
@@ -174,6 +174,16 @@ void VariableTest::testBuiltins()
 
     QString out;
 
+    // Test invalid ones:
+    editor->expandText(QStringLiteral("%{}"), view, out);
+    QCOMPARE(out, QStringLiteral("%{}"));
+    editor->expandText(QStringLiteral("%{"), view, out);
+    QCOMPARE(out, QStringLiteral("%{"));
+    editor->expandText(QStringLiteral("%{{}"), view, out);
+    QCOMPARE(out, QStringLiteral("%{{}"));
+    editor->expandText(QStringLiteral("%{{}}"), view, out);
+    QCOMPARE(out, QStringLiteral("%{{}}"));
+
     // Document:FileBaseName
     editor->expandText(QStringLiteral("%{Document:FileBaseName}"), view, out);
     QCOMPARE(out, QStringLiteral("kate-v5"));
@@ -284,6 +294,10 @@ void VariableTest::testBuiltins()
     editor->expandText(QStringLiteral("%{JS:3 + %{JS:2 + 1}}"), view, out);
     QCOMPARE(out, QStringLiteral("6"));
 
+    // PercentEncoded: since 5.67
+    editor->expandText(QStringLiteral("%{PercentEncoded:{a&b+c=d} \"}"), view, out);
+    QCOMPARE(out, QStringLiteral("%7Ba%26b%2Bc%3Dd%7D%20%22"));
+
     // UUID
     editor->expandText(QStringLiteral("%{UUID}"), view, out);
     QCOMPARE(out.count(QLatin1Char('-')), 4);
