@@ -1,29 +1,29 @@
-/*  This file is part of the KTextEditor project.
- *
- *  Copyright (C) 2017 KDE Developers
- *
- *  This library is free software; you can redistribute it and/or
- *  modify it under the terms of the GNU Library General Public
- *  License as published by the Free Software Foundation; either
- *  version 2 of the License, or (at your option) any later version.
- *
- *  This library is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- *  Library General Public License for more details.
- *
- *  You should have received a copy of the GNU Library General Public License
- *  along with this library; see the file COPYING.LIB.  If not, write to
- *  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- *  Boston, MA 02110-1301, USA.
- */
+/*  SPDX-License-Identifier: LGPL-2.0-or-later
+
+    Copyright (C) 2017 KDE Developers
+
+    This library is free software; you can redistribute it and/or
+    modify it under the terms of the GNU Library General Public
+    License as published by the Free Software Foundation; either
+    version 2 of the License, or (at your option) any later version.
+
+    This library is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+    Library General Public License for more details.
+
+    You should have received a copy of the GNU Library General Public License
+    along with this library; see the file COPYING.LIB.  If not, write to
+    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+    Boston, MA 02110-1301, USA.
+*/
 
 #ifndef KATE_SECURE_TEXTBUFFER_P_H
 #define KATE_SECURE_TEXTBUFFER_P_H
 
+#include <QCryptographicHash>
 #include <QObject>
 #include <QString>
-#include <QCryptographicHash>
 
 #include <kauth.h>
 
@@ -43,10 +43,13 @@ class SecureTextBuffer : public QObject
     Q_OBJECT
 
 public:
+    SecureTextBuffer()
+    {
+    }
 
-    SecureTextBuffer() {}
-
-    ~SecureTextBuffer() {}
+    ~SecureTextBuffer()
+    {
+    }
 
     /**
      * Common helper method
@@ -59,8 +62,7 @@ private:
     /**
      * Saves file contents using sets permissions.
      */
-    static bool saveFileInternal(const QString &sourceFile, const QString &targetFile,
-                                        const QByteArray &checksum, const uint ownerId, const uint groupId);
+    static bool saveFileInternal(const QString &sourceFile, const QString &targetFile, const QByteArray &checksum, const uint ownerId, const uint groupId);
 
     static bool moveFile(const QString &sourceFile, const QString &targetFile);
 
@@ -70,7 +72,6 @@ public Q_SLOTS:
      * We keep this code in one method to prevent multiple KAuth user queries during one save action.
      */
     static ActionReply savefile(const QVariantMap &args);
-
 };
 
 #endif
