@@ -1,33 +1,32 @@
-/*  This file is part of the Kate project.
- *
- *  Copyright (C) 2013 Christoph Cullmann <cullmann@kde.org>
- *
- *  This library is free software; you can redistribute it and/or
- *  modify it under the terms of the GNU Library General Public
- *  License as published by the Free Software Foundation; either
- *  version 2 of the License, or (at your option) any later version.
- *
- *  This library is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- *  Library General Public License for more details.
- *
- *  You should have received a copy of the GNU Library General Public License
- *  along with this library; see the file COPYING.LIB.  If not, write to
- *  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- *  Boston, MA 02110-1301, USA.
- */
+/*  SPDX-License-Identifier: LGPL-2.0-or-later
+
+    Copyright (C) 2013 Christoph Cullmann <cullmann@kde.org>
+
+    This library is free software; you can redistribute it and/or
+    modify it under the terms of the GNU Library General Public
+    License as published by the Free Software Foundation; either
+    version 2 of the License, or (at your option) any later version.
+
+    This library is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+    Library General Public License for more details.
+
+    You should have received a copy of the GNU Library General Public License
+    along with this library; see the file COPYING.LIB.  If not, write to
+    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+    Boston, MA 02110-1301, USA.
+*/
 
 #include "katetextfolding.h"
+#include "documentcursor.h"
 #include "katetextbuffer.h"
 #include "katetextrange.h"
-#include "documentcursor.h"
 
 #include <QJsonObject>
 
 namespace Kate
 {
-
 TextFolding::FoldingRange::FoldingRange(TextBuffer &buffer, const KTextEditor::Range &range, FoldingRangeFlags _flags)
     : start(new TextCursor(buffer, range.start(), KTextEditor::MovingCursor::MoveOnInsert))
     , end(new TextCursor(buffer, range.end(), KTextEditor::MovingCursor::MoveOnInsert))
@@ -121,9 +120,7 @@ qint64 TextFolding::newFoldingRange(const KTextEditor::Range &range, FoldingRang
      * check and bail out if that happens
      * bail out, too, if it can't be inserted!
      */
-    if (!newRange->start->isValid()
-            || !newRange->end->isValid()
-            || !insertNewFoldingRange(nullptr /* no parent here */, m_foldingRanges, newRange)) {
+    if (!newRange->start->isValid() || !newRange->end->isValid() || !insertNewFoldingRange(nullptr /* no parent here */, m_foldingRanges, newRange)) {
         /**
          * cleanup and be done
          */
@@ -236,12 +233,12 @@ bool TextFolding::unfoldRange(qint64 id, bool remove)
          */
         FoldingRange::Vector &parentVector = range->parent ? range->parent->nestedRanges : m_foldingRanges;
         FoldingRange::Vector newParentVector;
-        Q_FOREACH (FoldingRange *curRange, parentVector) {
+        for (FoldingRange *curRange : qAsConst(parentVector)) {
             /**
              * insert our nested ranges and reparent them
              */
             if (curRange == range) {
-                Q_FOREACH (FoldingRange *newRange, range->nestedRanges) {
+                for (FoldingRange *newRange : qAsConst(range->nestedRanges)) {
                     newRange->parent = range->parent;
                     newParentVector.push_back(newRange);
                 }
@@ -303,7 +300,7 @@ bool TextFolding::isLineVisible(int line, qint64 *foldedRangeId) const
     /**
      * search upper bound, index to item with start line higher than our one
      */
-    FoldingRange::Vector::const_iterator upperBound = qUpperBound(m_foldedFoldingRanges.begin(), m_foldedFoldingRanges.end(), line, compareRangeByStartWithLine);
+    FoldingRange::Vector::const_iterator upperBound = std::upper_bound(m_foldedFoldingRanges.begin(), m_foldedFoldingRanges.end(), line, compareRangeByStartWithLine);
     if (upperBound != m_foldedFoldingRanges.begin()) {
         --upperBound;
     }
@@ -349,7 +346,7 @@ void TextFolding::ensureLineIsVisible(int line)
          * unfold shall work!
          */
         const bool unfolded = unfoldRange(foldedRangeId);
-        (void) unfolded;
+        (void)unfolded;
         Q_ASSERT(unfolded);
     }
 }
@@ -371,7 +368,7 @@ int TextFolding::visibleLines() const
     /**
      * count all folded lines and subtract them from visible lines
      */
-    Q_FOREACH (FoldingRange *range, m_foldedFoldingRanges) {
+    for (FoldingRange *range : m_foldedFoldingRanges) {
         visibleLines -= (range->end->line() - range->start->line());
     }
 
@@ -407,7 +404,7 @@ int TextFolding::lineToVisibleLine(int line) const
      */
     int seenVisibleLines = 0;
     int lastLine = 0;
-    Q_FOREACH (FoldingRange *range, m_foldedFoldingRanges) {
+    for (FoldingRange *range : m_foldedFoldingRanges) {
         /**
          * abort if we reach our line!
          */
@@ -466,7 +463,7 @@ int TextFolding::visibleLineToLine(int visibleLine) const
     int seenVisibleLines = 0;
     int lastLine = 0;
     int lastLineVisibleLines = 0;
-    Q_FOREACH (FoldingRange *range, m_foldedFoldingRanges) {
+    for (FoldingRange *range : m_foldedFoldingRanges) {
         /**
          * else compute visible lines and move last seen
          */
@@ -498,12 +495,12 @@ int TextFolding::visibleLineToLine(int visibleLine) const
     return line;
 }
 
-QVector<QPair<qint64, TextFolding::FoldingRangeFlags> > TextFolding::foldingRangesStartingOnLine(int line) const
+QVector<QPair<qint64, TextFolding::FoldingRangeFlags>> TextFolding::foldingRangesStartingOnLine(int line) const
 {
     /**
      * results vector
      */
-    QVector<QPair<qint64, TextFolding::FoldingRangeFlags> > results;
+    QVector<QPair<qint64, TextFolding::FoldingRangeFlags>> results;
 
     /**
      * recursively do binary search
@@ -516,7 +513,7 @@ QVector<QPair<qint64, TextFolding::FoldingRangeFlags> > TextFolding::foldingRang
     return results;
 }
 
-void TextFolding::foldingRangesStartingOnLine(QVector<QPair<qint64, FoldingRangeFlags> > &results, const TextFolding::FoldingRange::Vector &ranges, int line) const
+void TextFolding::foldingRangesStartingOnLine(QVector<QPair<qint64, FoldingRangeFlags>> &results, const TextFolding::FoldingRange::Vector &ranges, int line) const
 {
     /**
      * early out for no folds
@@ -528,12 +525,12 @@ void TextFolding::foldingRangesStartingOnLine(QVector<QPair<qint64, FoldingRange
     /**
      * first: lower bound of start
      */
-    FoldingRange::Vector::const_iterator lowerBound = qLowerBound(ranges.begin(), ranges.end(), line, compareRangeByLineWithStart);
+    FoldingRange::Vector::const_iterator lowerBound = std::lower_bound(ranges.begin(), ranges.end(), line, compareRangeByLineWithStart);
 
     /**
      * second: upper bound of end
      */
-    FoldingRange::Vector::const_iterator upperBound = qUpperBound(ranges.begin(), ranges.end(), line, compareRangeByStartWithLine);
+    FoldingRange::Vector::const_iterator upperBound = std::upper_bound(ranges.begin(), ranges.end(), line, compareRangeByStartWithLine);
 
     /**
      * we may need to go one to the left, if not already at the begin, as we might overlap with the one in front of us!
@@ -560,7 +557,7 @@ void TextFolding::foldingRangesStartingOnLine(QVector<QPair<qint64, FoldingRange
     }
 }
 
-QVector<QPair<qint64, TextFolding::FoldingRangeFlags> > TextFolding::foldingRangesForParentRange(qint64 parentRangeId) const
+QVector<QPair<qint64, TextFolding::FoldingRangeFlags>> TextFolding::foldingRangesForParentRange(qint64 parentRangeId) const
 {
     /**
      * toplevel ranges requested or real parent?
@@ -575,7 +572,7 @@ QVector<QPair<qint64, TextFolding::FoldingRangeFlags> > TextFolding::foldingRang
     /**
      * no ranges => nothing to do
      */
-    QVector<QPair<qint64, FoldingRangeFlags> > results;
+    QVector<QPair<qint64, FoldingRangeFlags>> results;
     if (!ranges)
         return results;
 
@@ -608,14 +605,14 @@ QString TextFolding::debugDump(const TextFolding::FoldingRange::Vector &ranges,
      * dump all ranges recursively
      */
     QString dump;
-    Q_FOREACH (FoldingRange *range, ranges) {
+    for (FoldingRange *range : ranges) {
         if (!dump.isEmpty()) {
             dump += QLatin1Char(' ');
         }
 
         const QString persistent = (range->flags & Persistent) ? QStringLiteral("p") : QString();
         const QString folded = (range->flags & Folded) ? QStringLiteral("f") : QString();
-        dump += QString::fromLatin1("[%1:%2 %3%4 ").arg(range->start->line()).arg(range->start->column()).arg(persistent, folded);
+        dump += QStringLiteral("[%1:%2 %3%4 ").arg(range->start->line()).arg(range->start->column()).arg(persistent, folded);
 
         /**
          * recurse
@@ -627,7 +624,7 @@ QString TextFolding::debugDump(const TextFolding::FoldingRange::Vector &ranges,
             }
         }
 
-        dump += QString::fromLatin1("%1:%2]").arg(range->end->line()).arg(range->end->column());
+        dump += QStringLiteral("%1:%2]").arg(range->end->line()).arg(range->end->column());
     }
     return dump;
 }
@@ -642,12 +639,12 @@ bool TextFolding::insertNewFoldingRange(FoldingRange *parent, FoldingRange::Vect
     /**
      * first: lower bound of start
      */
-    FoldingRange::Vector::iterator lowerBound = qLowerBound(existingRanges.begin(), existingRanges.end(), newRange, compareRangeByStart);
+    FoldingRange::Vector::iterator lowerBound = std::lower_bound(existingRanges.begin(), existingRanges.end(), newRange, compareRangeByStart);
 
     /**
      * second: upper bound of end
      */
-    FoldingRange::Vector::iterator upperBound = qUpperBound(existingRanges.begin(), existingRanges.end(), newRange, compareRangeByEnd);
+    FoldingRange::Vector::iterator upperBound = std::upper_bound(existingRanges.begin(), existingRanges.end(), newRange, compareRangeByEnd);
 
     /**
      * we may need to go one to the left, if not already at the begin, as we might overlap with the one in front of us!
@@ -748,7 +745,7 @@ bool TextFolding::insertNewFoldingRange(FoldingRange *parent, FoldingRange::Vect
      * correct parent mapping!
      */
     newRange->parent = parent;
-    Q_FOREACH (FoldingRange *range, newRange->nestedRanges) {
+    for (FoldingRange *range : qAsConst(newRange->nestedRanges)) {
         range->parent = newRange;
     }
 
@@ -812,7 +809,7 @@ bool TextFolding::updateFoldedRangesForNewRange(TextFolding::FoldingRange *newRa
      */
     FoldingRange::Vector newFoldedFoldingRanges;
     bool newRangeInserted = false;
-    Q_FOREACH (FoldingRange *range, m_foldedFoldingRanges) {
+    for (FoldingRange *range : qAsConst(m_foldedFoldingRanges)) {
         /**
          * contained? kill
          */
@@ -886,12 +883,12 @@ bool TextFolding::updateFoldedRangesForRemovedRange(TextFolding::FoldingRange *o
     }
 
     /**
-    * ok, if we arrive here, we are a unfolded range and we have no folded parent
-    * we now want to remove this range from the m_foldedFoldingRanges vector and include our nested folded ranges!
-    * TODO: OPTIMIZE
-    */
+     * ok, if we arrive here, we are a unfolded range and we have no folded parent
+     * we now want to remove this range from the m_foldedFoldingRanges vector and include our nested folded ranges!
+     * TODO: OPTIMIZE
+     */
     FoldingRange::Vector newFoldedFoldingRanges;
-    Q_FOREACH (FoldingRange *range, m_foldedFoldingRanges) {
+    for (FoldingRange *range : qAsConst(m_foldedFoldingRanges)) {
         /**
          * right range? insert folded nested ranges
          */
@@ -927,7 +924,7 @@ void TextFolding::appendFoldedRanges(TextFolding::FoldingRange::Vector &newFolde
     /**
      * search for folded ranges and append them
      */
-    Q_FOREACH (FoldingRange *range, ranges) {
+    for (FoldingRange *range : ranges) {
         /**
          * itself folded? append
          */
@@ -957,7 +954,7 @@ void TextFolding::exportFoldingRanges(const TextFolding::FoldingRange::Vector &r
     /**
      * dump all ranges recursively
      */
-    Q_FOREACH (FoldingRange *range, ranges) {
+    for (FoldingRange *range : ranges) {
         /**
          * construct one range and dump to folds
          */
@@ -978,17 +975,19 @@ void TextFolding::exportFoldingRanges(const TextFolding::FoldingRange::Vector &r
 
 void TextFolding::importFoldingRanges(const QJsonDocument &folds)
 {
-    Q_FOREACH (FoldingRange *range, m_foldingRanges) {
+    for (FoldingRange *range : qAsConst(m_foldingRanges)) {
         unfoldRange(range->id);
     }
+
     /**
      * try to create all folding ranges
      */
-    Q_FOREACH (const QJsonValue &rangeVariant, folds.array()) {
+    const auto jsonRanges = folds.array();
+    for (const auto &rangeVariant : jsonRanges) {
         /**
          * get map
          */
-        QJsonObject rangeMap = rangeVariant.toObject();
+        const auto rangeMap = rangeVariant.toObject();
 
         /**
          * construct range start/end
@@ -1001,10 +1000,7 @@ void TextFolding::importFoldingRanges(const QJsonDocument &folds)
          */
         if (start >= end ||
             (m_buffer.document() && // <-- unit test katetextbuffertest does not have a KTE::Document assigned
-               (!KTextEditor::DocumentCursor(m_buffer.document(), start).isValidTextPosition() ||
-                !KTextEditor::DocumentCursor(m_buffer.document(), end).isValidTextPosition()))
-           )
-        {
+             (!KTextEditor::DocumentCursor(m_buffer.document(), start).isValidTextPosition() || !KTextEditor::DocumentCursor(m_buffer.document(), end).isValidTextPosition()))) {
             continue;
         }
 
