@@ -1,34 +1,34 @@
-/*  This file is part of the KDE libraries and the Kate part.
- *
- *  Copyright (C) 2007 David Nolden <david.nolden.kdevelop@art-master.de>
- *
- *  This library is free software; you can redistribute it and/or
- *  modify it under the terms of the GNU Library General Public
- *  License as published by the Free Software Foundation; either
- *  version 2 of the License, or (at your option) any later version.
- *
- *  This library is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- *  Library General Public License for more details.
- *
- *  You should have received a copy of the GNU Library General Public License
- *  along with this library; see the file COPYING.LIB.  If not, write to
- *  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- *  Boston, MA 02110-1301, USA.
- */
+/*  SPDX-License-Identifier: LGPL-2.0-or-later
+
+    Copyright (C) 2007 David Nolden <david.nolden.kdevelop@art-master.de>
+
+    This library is free software; you can redistribute it and/or
+    modify it under the terms of the GNU Library General Public
+    License as published by the Free Software Foundation; either
+    version 2 of the License, or (at your option) any later version.
+
+    This library is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+    Library General Public License for more details.
+
+    You should have received a copy of the GNU Library General Public License
+    along with this library; see the file COPYING.LIB.  If not, write to
+    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+    Boston, MA 02110-1301, USA.
+*/
 
 #include "kateargumenthinttree.h"
 
-#include <QHeaderView>
 #include <QApplication>
 #include <QDesktopWidget>
+#include <QHeaderView>
 #include <QScrollBar>
 
-#include "kateargumenthintmodel.h"
-#include "katecompletionwidget.h"
 #include "expandingtree/expandingwidgetmodel.h"
+#include "kateargumenthintmodel.h"
 #include "katecompletiondelegate.h"
+#include "katecompletionwidget.h"
 #include "kateview.h"
 #include <QModelIndex>
 
