@@ -25,79 +25,77 @@
    Boston, MA 02110-1301, USA.
 */
 
-//BEGIN Includes
+// BEGIN Includes
 #include "katedialogs.h"
 
-#include <ktexteditor_version.h>
 #include <ktexteditor/message.h>
+#include <ktexteditor_version.h>
 
 #include "kateautoindent.h"
 #include "katebuffer.h"
 #include "kateconfig.h"
 #include "katedocument.h"
 #include "kateglobal.h"
-#include "kateschema.h"
 #include "katemodeconfigpage.h"
+#include "kateschema.h"
 #include "kateview.h"
 #include "spellcheck/spellcheck.h"
 
 // auto generated ui files
-#include "ui_textareaappearanceconfigwidget.h"
 #include "ui_bordersappearanceconfigwidget.h"
-#include "ui_navigationconfigwidget.h"
+#include "ui_completionconfigtab.h"
 #include "ui_editconfigwidget.h"
 #include "ui_indentationconfigwidget.h"
-#include "ui_completionconfigtab.h"
-#include "ui_opensaveconfigwidget.h"
+#include "ui_navigationconfigwidget.h"
 #include "ui_opensaveconfigadvwidget.h"
+#include "ui_opensaveconfigwidget.h"
 #include "ui_spellcheckconfigwidget.h"
+#include "ui_textareaappearanceconfigwidget.h"
 
 #include <KIO/Job>
-#include <kjobwidgets.h>
 
+#include "kateabstractinputmodefactory.h"
+#include "katepartdebug.h"
+#include <KActionCollection>
 #include <KCharsets>
 #include <KColorCombo>
 #include <KComboBox>
-#include <KIconLoader>
-#include "katepartdebug.h"
-#include "kateabstractinputmodefactory.h"
-#include <KShortcutsDialog>
 #include <KLineEdit>
 #include <KMessageBox>
 #include <KProcess>
 #include <KRun>
 #include <KSeparator>
-#include <KActionCollection>
+#include <KShortcutsDialog>
 
-#include <QFile>
-#include <QClipboard>
-#include <QMap>
-#include <QStringList>
-#include <QTextCodec>
-#include <QTextStream>
-#include <QTemporaryFile>
-#include <QKeyEvent>
-#include <QPainter>
 #include <QCheckBox>
+#include <QClipboard>
 #include <QComboBox>
 #include <QDialog>
+#include <QDomDocument>
+#include <QFile>
 #include <QFileDialog>
 #include <QGroupBox>
+#include <QKeyEvent>
 #include <QLabel>
 #include <QLayout>
+#include <QMap>
+#include <QPainter>
 #include <QRadioButton>
 #include <QSettings>
 #include <QSlider>
 #include <QSpinBox>
+#include <QStringList>
 #include <QTabBar>
 #include <QTabWidget>
+#include <QTemporaryFile>
+#include <QTextCodec>
+#include <QTextStream>
 #include <QToolButton>
 #include <QWhatsThis>
-#include <QDomDocument>
 
-//END
+// END
 
-//BEGIN KateIndentConfigTab
+// BEGIN KateIndentConfigTab
 KateIndentConfigTab::KateIndentConfigTab(QWidget *parent)
     : KateConfigPage(parent)
 {
@@ -223,9 +221,9 @@ QString KateIndentConfigTab::name() const
     return i18n("Indentation");
 }
 
-//END KateIndentConfigTab
+// END KateIndentConfigTab
 
-//BEGIN KateCompletionConfigTab
+// BEGIN KateCompletionConfigTab
 KateCompletionConfigTab::KateCompletionConfigTab(QWidget *parent)
     : KateConfigPage(parent)
 {
@@ -296,9 +294,9 @@ QString KateCompletionConfigTab::name() const
     return i18n("Auto Completion");
 }
 
-//END KateCompletionConfigTab
+// END KateCompletionConfigTab
 
-//BEGIN KateSpellCheckConfigTab
+// BEGIN KateSpellCheckConfigTab
 KateSpellCheckConfigTab::KateSpellCheckConfigTab(QWidget *parent)
     : KateConfigPage(parent)
 {
@@ -348,7 +346,8 @@ void KateSpellCheckConfigTab::apply()
     KateDocumentConfig::global()->setOnTheFlySpellCheck(settings.value(QStringLiteral("checkerEnabledByDefault"), false).toBool());
     KateDocumentConfig::global()->configEnd();
 
-    foreach (KTextEditor::DocumentPrivate *doc, KTextEditor::EditorPrivate::self()->kateDocuments()) {
+    const auto docs = KTextEditor::EditorPrivate::self()->kateDocuments();
+    for (KTextEditor::DocumentPrivate *doc : docs) {
         doc->refreshOnTheFlyCheck();
     }
 }
@@ -363,9 +362,9 @@ QString KateSpellCheckConfigTab::name() const
     return i18n("Spellcheck");
 }
 
-//END KateSpellCheckConfigTab
+// END KateSpellCheckConfigTab
 
-//BEGIN KateNavigationConfigTab
+// BEGIN KateNavigationConfigTab
 KateNavigationConfigTab::KateNavigationConfigTab(QWidget *parent)
     : KateConfigPage(parent)
 {
@@ -437,9 +436,9 @@ QString KateNavigationConfigTab::name() const
     return i18n("Text Navigation");
 }
 
-//END KateNavigationConfigTab
+// END KateNavigationConfigTab
 
-//BEGIN KateEditGeneralConfigTab
+// BEGIN KateEditGeneralConfigTab
 KateEditGeneralConfigTab::KateEditGeneralConfigTab(QWidget *parent)
     : KateConfigPage(parent)
 {
@@ -448,8 +447,8 @@ KateEditGeneralConfigTab::KateEditGeneralConfigTab(QWidget *parent)
     ui = new Ui::EditConfigWidget();
     ui->setupUi(newWidget);
 
-    QList<KateAbstractInputModeFactory *> inputModes = KTextEditor::EditorPrivate::self()->inputModeFactories();
-    Q_FOREACH(KateAbstractInputModeFactory *fact, inputModes) {
+    const QList<KateAbstractInputModeFactory *> inputModes = KTextEditor::EditorPrivate::self()->inputModeFactories();
+    for (KateAbstractInputModeFactory *fact : inputModes) {
         ui->cmbInputMode->addItem(fact->name(), static_cast<int>(fact->inputMode()));
     }
 
@@ -472,7 +471,7 @@ KateEditGeneralConfigTab::KateEditGeneralConfigTab(QWidget *parent)
             ui->cmbEncloseSelection->removeItem(index);
             slotChanged();
 
-        // Not already there? Add new item! For whatever reason it isn't done automatically
+            // Not already there? Add new item! For whatever reason it isn't done automatically
         } else if (ui->cmbEncloseSelection->findText(text) < 0) {
             ui->cmbEncloseSelection->addItem(text);
             slotChanged();
@@ -509,7 +508,8 @@ void KateEditGeneralConfigTab::apply()
 
     KateViewConfig::global()->setValue(KateViewConfig::AutoBrackets, ui->chkAutoBrackets->isChecked());
     KateViewConfig::global()->setValue(KateViewConfig::CharsToEncloseSelection, ui->cmbEncloseSelection->currentText());
-    QStringList userLetters; for (int i = UserData; i < ui->cmbEncloseSelection->count(); ++i) {
+    QStringList userLetters;
+    for (int i = UserData; i < ui->cmbEncloseSelection->count(); ++i) {
         userLetters.append(ui->cmbEncloseSelection->itemText(i));
     }
     KateViewConfig::global()->setValue(KateViewConfig::UserSetsOfCharsToEncloseSelection, userLetters);
@@ -536,7 +536,7 @@ void KateEditGeneralConfigTab::reload()
 
     ui->cmbEncloseSelection->clear();
     ui->cmbEncloseSelection->lineEdit()->setClearButtonEnabled(true);
-    ui->cmbEncloseSelection->lineEdit()->setPlaceholderText(QStringLiteral("Feature is not active"));
+    ui->cmbEncloseSelection->lineEdit()->setPlaceholderText(i18n("Feature is not active"));
     ui->cmbEncloseSelection->addItem(QString(), None);
     ui->cmbEncloseSelection->setItemData(0, i18n("Disable Feature"), Qt::ToolTipRole);
     ui->cmbEncloseSelection->addItem(QStringLiteral("`*_~"), MarkDown);
@@ -553,7 +553,6 @@ void KateEditGeneralConfigTab::reload()
 
     const int id = static_cast<int>(KateViewConfig::global()->inputMode());
     ui->cmbInputMode->setCurrentIndex(ui->cmbInputMode->findData(id));
-
 }
 
 QString KateEditGeneralConfigTab::name() const
@@ -561,9 +560,9 @@ QString KateEditGeneralConfigTab::name() const
     return i18n("General");
 }
 
-//END KateEditGeneralConfigTab
+// END KateEditGeneralConfigTab
 
-//BEGIN KateEditConfigTab
+// BEGIN KateEditConfigTab
 KateEditConfigTab::KateEditConfigTab(QWidget *parent)
     : KateConfigPage(parent)
     , editConfigTab(new KateEditGeneralConfigTab(this))
@@ -590,7 +589,8 @@ KateEditConfigTab::KateEditConfigTab(QWidget *parent)
     observeChanges(spellCheckConfigTab);
 
     int i = tabWidget->count();
-    Q_FOREACH(KateAbstractInputModeFactory *factory, KTextEditor::EditorPrivate::self()->inputModeFactories()) {
+    const auto inputModeFactories = KTextEditor::EditorPrivate::self()->inputModeFactories();
+    for (KateAbstractInputModeFactory *factory : inputModeFactories) {
         KateConfigPage *tab = factory->createConfigPage(this);
         if (tab) {
             m_inputModeConfigTabs << tab;
@@ -617,7 +617,7 @@ void KateEditConfigTab::apply()
     indentConfigTab->apply();
     completionConfigTab->apply();
     spellCheckConfigTab->apply();
-    Q_FOREACH(KateConfigPage *tab, m_inputModeConfigTabs) {
+    for (KateConfigPage *tab : qAsConst(m_inputModeConfigTabs)) {
         tab->apply();
     }
 }
@@ -629,7 +629,7 @@ void KateEditConfigTab::reload()
     indentConfigTab->reload();
     completionConfigTab->reload();
     spellCheckConfigTab->reload();
-    Q_FOREACH(KateConfigPage *tab, m_inputModeConfigTabs) {
+    for (KateConfigPage *tab : qAsConst(m_inputModeConfigTabs)) {
         tab->reload();
     }
 }
@@ -641,7 +641,7 @@ void KateEditConfigTab::reset()
     indentConfigTab->reset();
     completionConfigTab->reset();
     spellCheckConfigTab->reset();
-    Q_FOREACH(KateConfigPage *tab, m_inputModeConfigTabs) {
+    for (KateConfigPage *tab : qAsConst(m_inputModeConfigTabs)) {
         tab->reset();
     }
 }
@@ -653,7 +653,7 @@ void KateEditConfigTab::defaults()
     indentConfigTab->defaults();
     completionConfigTab->defaults();
     spellCheckConfigTab->defaults();
-    Q_FOREACH(KateConfigPage *tab, m_inputModeConfigTabs) {
+    for (KateConfigPage *tab : qAsConst(m_inputModeConfigTabs)) {
         tab->defaults();
     }
 }
@@ -673,9 +673,9 @@ QIcon KateEditConfigTab::icon() const
     return QIcon::fromTheme(QStringLiteral("accessories-text-editor"));
 }
 
-//END KateEditConfigTab
+// END KateEditConfigTab
 
-//BEGIN KateViewDefaultsConfig
+// BEGIN KateViewDefaultsConfig
 KateViewDefaultsConfig::KateViewDefaultsConfig(QWidget *parent)
     : KateConfigPage(parent)
     , textareaUi(new Ui::TextareaAppearanceConfigWidget())
@@ -703,6 +703,7 @@ KateViewDefaultsConfig::KateViewDefaultsConfig(QWidget *parent)
     reload();
 
     observeChanges(textareaUi->chkAnimateBracketMatching);
+    observeChanges(textareaUi->chkDynWrapAnywhere);
     observeChanges(textareaUi->chkDynWrapAtStaticMarker);
     observeChanges(textareaUi->chkFoldFirstLine);
     observeChanges(textareaUi->chkShowIndentationLines);
@@ -762,6 +763,7 @@ void KateViewDefaultsConfig::apply()
     KateViewConfig::global()->setValue(KateViewConfig::BookmarkSorting, bordersUi->rbSortBookmarksByPosition->isChecked() ? 0 : 1);
     KateViewConfig::global()->setValue(KateViewConfig::DynWordWrapAlignIndent, textareaUi->sbDynamicWordWrapDepth->value());
     KateViewConfig::global()->setValue(KateViewConfig::DynWordWrapIndicators, textareaUi->cmbDynamicWordWrapIndicator->currentIndex());
+    KateViewConfig::global()->setValue(KateViewConfig::DynWrapAnywhere, textareaUi->chkDynWrapAnywhere->isChecked());
     KateViewConfig::global()->setValue(KateViewConfig::DynWrapAtStaticMarker, textareaUi->chkDynWrapAtStaticMarker->isChecked());
     KateViewConfig::global()->setValue(KateViewConfig::FoldFirstLine, textareaUi->chkFoldFirstLine->isChecked());
     KateViewConfig::global()->setValue(KateViewConfig::ScrollBarMiniMapWidth, bordersUi->spBoxMiniMapWidth->value());
@@ -798,6 +800,7 @@ void KateViewDefaultsConfig::reload()
     bordersUi->spBoxMiniMapWidth->setValue(KateViewConfig::global()->scrollBarMiniMapWidth());
 
     textareaUi->chkAnimateBracketMatching->setChecked(KateRendererConfig::global()->animateBracketMatching());
+    textareaUi->chkDynWrapAnywhere->setChecked(KateViewConfig::global()->dynWrapAnywhere());
     textareaUi->chkDynWrapAtStaticMarker->setChecked(KateViewConfig::global()->dynWrapAtStaticMarker());
     textareaUi->chkFoldFirstLine->setChecked(KateViewConfig::global()->foldFirstLine());
     textareaUi->chkShowIndentationLines->setChecked(KateRendererConfig::global()->showIndentationLines());
@@ -837,9 +840,9 @@ QIcon KateViewDefaultsConfig::icon() const
     return QIcon::fromTheme(QStringLiteral("preferences-desktop-theme"));
 }
 
-//END KateViewDefaultsConfig
+// END KateViewDefaultsConfig
 
-//BEGIN KateSaveConfigTab
+// BEGIN KateSaveConfigTab
 KateSaveConfigTab::KateSaveConfigTab(QWidget *parent)
     : KateConfigPage(parent)
     , modeConfigPage(new ModeConfigPage(this))
@@ -880,7 +883,13 @@ KateSaveConfigTab::KateSaveConfigTab(QWidget *parent)
     observeChanges(uiadv->chkBackupLocalFiles);
     observeChanges(uiadv->chkBackupRemoteFiles);
     observeChanges(uiadv->cmbSwapFileMode);
+#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
     connect(uiadv->cmbSwapFileMode, QOverload<int>::of(&QComboBox::currentIndexChanged), this, &KateSaveConfigTab::swapFileModeChanged);
+#else
+    connect(uiadv->cmbSwapFileMode, QOverload<int, const QString &>::of(&QComboBox::currentIndexChanged), this, &KateSaveConfigTab::swapFileModeChanged);
+#endif
+
+
     observeChanges(uiadv->edtBackupPrefix);
     observeChanges(uiadv->edtBackupSuffix);
     observeChanges(uiadv->kurlSwapDirectory);
@@ -900,6 +909,18 @@ KateSaveConfigTab::KateSaveConfigTab(QWidget *parent)
 
     layout->addWidget(tabWidget);
     setLayout(layout);
+
+    // support variable expansion in backup prefix/suffix
+    KTextEditor::Editor::instance()->addVariableExpansion({uiadv->edtBackupPrefix, uiadv->edtBackupSuffix},
+                                                          {QStringLiteral("Date:Locale"),
+                                                           QStringLiteral("Date:ISO"),
+                                                           QStringLiteral("Date:"),
+                                                           QStringLiteral("Time:Locale"),
+                                                           QStringLiteral("Time:ISO"),
+                                                           QStringLiteral("Time:"),
+                                                           QStringLiteral("ENV:"),
+                                                           QStringLiteral("JS:"),
+                                                           QStringLiteral("UUID")});
 }
 
 KateSaveConfigTab::~KateSaveConfigTab()
@@ -946,11 +967,7 @@ void KateSaveConfigTab::apply()
     KateDocumentConfig::global()->configStart();
 
     if (uiadv->edtBackupSuffix->text().isEmpty() && uiadv->edtBackupPrefix->text().isEmpty()) {
-        KMessageBox::information(
-            this,
-            i18n("You did not provide a backup suffix or prefix. Using default suffix: '~'"),
-            i18n("No Backup Suffix or Prefix")
-        );
+        KMessageBox::information(this, i18n("You did not provide a backup suffix or prefix. Using default suffix: '~'"), i18n("No Backup Suffix or Prefix"));
         uiadv->edtBackupSuffix->setText(QStringLiteral("~"));
     }
 
@@ -1016,8 +1033,8 @@ void KateSaveConfigTab::reload()
     // encoding detection
     ui->cmbEncodingDetection->clear();
     bool found = false;
-    for (int i = 0; !KEncodingProber::nameForProberType((KEncodingProber::ProberType) i).isEmpty(); ++i) {
-        ui->cmbEncodingDetection->addItem(KEncodingProber::nameForProberType((KEncodingProber::ProberType) i));
+    for (int i = 0; !KEncodingProber::nameForProberType((KEncodingProber::ProberType)i).isEmpty(); ++i) {
+        ui->cmbEncodingDetection->addItem(KEncodingProber::nameForProberType((KEncodingProber::ProberType)i));
         if (i == KateGlobalConfig::global()->proberType()) {
             ui->cmbEncodingDetection->setCurrentIndex(ui->cmbEncodingDetection->count() - 1);
             found = true;
@@ -1085,14 +1102,14 @@ QIcon KateSaveConfigTab::icon() const
     return QIcon::fromTheme(QStringLiteral("document-save"));
 }
 
-//END KateSaveConfigTab
+// END KateSaveConfigTab
 
-//BEGIN KateGotoBar
+// BEGIN KateGotoBar
 KateGotoBar::KateGotoBar(KTextEditor::View *view, QWidget *parent)
     : KateViewBarWidget(true, parent)
     , m_view(view)
 {
-    Q_ASSERT(m_view != nullptr);    // this bar widget is pointless w/o a view
+    Q_ASSERT(m_view != nullptr); // this bar widget is pointless w/o a view
 
     QHBoxLayout *topLayout = new QHBoxLayout(centralWidget());
     topLayout->setContentsMargins(0, 0, 0, 0);
@@ -1161,7 +1178,7 @@ bool KateGotoBar::eventFilter(QObject *object, QEvent *event)
             return false;
         }
 
-        int delta = static_cast<QWheelEvent *>(event)->delta();
+        int delta = static_cast<QWheelEvent *>(event)->angleDelta().y();
         // Reset m_wheelDelta when scroll direction change
         if (m_wheelDelta != 0 && (m_wheelDelta < 0) != (delta < 0)) {
             m_wheelDelta = 0;
@@ -1189,13 +1206,11 @@ void KateGotoBar::gotoClipboard()
         m_gotoRange->setValue(lineNo);
         gotoLine();
     } else {
-        QPointer<KTextEditor::Message> message = new KTextEditor::Message(
-            i18n("No valid line number found in clipboard"));
+        QPointer<KTextEditor::Message> message = new KTextEditor::Message(i18n("No valid line number found in clipboard"));
         message->setWordWrap(true);
         message->setAutoHide(2000);
         message->setPosition(KTextEditor::Message::BottomInView);
-        message->setView(m_view),
-        m_view->document()->postMessage(message);
+        message->setView(m_view), m_view->document()->postMessage(message);
     }
 }
 
@@ -1231,9 +1246,9 @@ void KateGotoBar::gotoLine()
     m_view->setFocus();
     emit hideMe();
 }
-//END KateGotoBar
+// END KateGotoBar
 
-//BEGIN KateDictionaryBar
+// BEGIN KateDictionaryBar
 KateDictionaryBar::KateDictionaryBar(KTextEditor::ViewPrivate *view, QWidget *parent)
     : KateViewBarWidget(true, parent)
     , m_view(view)
@@ -1242,12 +1257,10 @@ KateDictionaryBar::KateDictionaryBar(KTextEditor::ViewPrivate *view, QWidget *pa
 
     QHBoxLayout *topLayout = new QHBoxLayout(centralWidget());
     topLayout->setContentsMargins(0, 0, 0, 0);
-    //topLayout->setSpacing(spacingHint());
+    // topLayout->setSpacing(spacingHint());
     m_dictionaryComboBox = new Sonnet::DictionaryComboBox(centralWidget());
-    connect(m_dictionaryComboBox, SIGNAL(dictionaryChanged(QString)),
-            this, SLOT(dictionaryChanged(QString)));
-    connect(view->doc(), SIGNAL(defaultDictionaryChanged(KTextEditor::DocumentPrivate*)),
-            this, SLOT(updateData()));
+    connect(m_dictionaryComboBox, SIGNAL(dictionaryChanged(QString)), this, SLOT(dictionaryChanged(QString)));
+    connect(view->doc(), SIGNAL(defaultDictionaryChanged(KTextEditor::DocumentPrivate *)), this, SLOT(updateData()));
     QLabel *label = new QLabel(i18n("Dictionary:"), centralWidget());
     label->setBuddy(m_dictionaryComboBox);
 
@@ -1282,12 +1295,10 @@ void KateDictionaryBar::dictionaryChanged(const QString &dictionary)
     }
 }
 
-//END KateGotoBar
+// END KateGotoBar
 
-//BEGIN KateModOnHdPrompt
-KateModOnHdPrompt::KateModOnHdPrompt(KTextEditor::DocumentPrivate *doc,
-                                     KTextEditor::ModificationInterface::ModifiedOnDiskReason modtype,
-                                     const QString &reason)
+// BEGIN KateModOnHdPrompt
+KateModOnHdPrompt::KateModOnHdPrompt(KTextEditor::DocumentPrivate *doc, KTextEditor::ModificationInterface::ModifiedOnDiskReason modtype, const QString &reason)
     : QObject(doc)
     , m_doc(doc)
     , m_modtype(modtype)
@@ -1302,7 +1313,7 @@ KateModOnHdPrompt::KateModOnHdPrompt(KTextEditor::DocumentPrivate *doc,
     // If the file isn't deleted, present a diff button
     const bool onDiskDeleted = modtype == KTextEditor::ModificationInterface::OnDiskDeleted;
     if (!onDiskDeleted) {
-        QAction * aAutoReload = new QAction(i18n("Enable Auto Reload"), this);
+        QAction *aAutoReload = new QAction(i18n("Enable Auto Reload"), this);
         aAutoReload->setIcon(QIcon::fromTheme(QStringLiteral("view-refresh")));
         aAutoReload->setToolTip(i18n("Will never again warn about on disk changes but always reload."));
         m_message->addAction(aAutoReload, false);
@@ -1315,26 +1326,26 @@ KateModOnHdPrompt::KateModOnHdPrompt(KTextEditor::DocumentPrivate *doc,
             connect(m_diffAction, SIGNAL(triggered()), this, SLOT(slotDiff()));
         }
 
-        QAction * aReload = new QAction(i18n("&Reload"), this);
+        QAction *aReload = new QAction(i18n("&Reload"), this);
         aReload->setIcon(QIcon::fromTheme(QStringLiteral("view-refresh")));
         aReload->setToolTip(i18n("Reload the file from disk. Unsaved changes will be lost."));
         m_message->addAction(aReload);
         connect(aReload, SIGNAL(triggered()), this, SIGNAL(reloadTriggered()));
     } else {
-        QAction * closeFile = new QAction(i18nc("@action:button closes the opened file", "&Close File"), this);
+        QAction *closeFile = new QAction(i18nc("@action:button closes the opened file", "&Close File"), this);
         closeFile->setIcon(QIcon::fromTheme(QStringLiteral("document-close")));
         closeFile->setToolTip(i18n("Close the file, discarding its content."));
         m_message->addAction(closeFile, false);
         connect(closeFile, &QAction::triggered, this, &KateModOnHdPrompt::closeTriggered);
 
-        QAction * aSaveAs = new QAction(i18n("&Save As..."), this);
+        QAction *aSaveAs = new QAction(i18n("&Save As..."), this);
         aSaveAs->setIcon(QIcon::fromTheme(QStringLiteral("document-save-as")));
         aSaveAs->setToolTip(i18n("Lets you select a location and save the file again."));
         m_message->addAction(aSaveAs, false);
         connect(aSaveAs, SIGNAL(triggered()), this, SIGNAL(saveAsTriggered()));
     }
 
-    QAction * aIgnore = new QAction(i18n("&Ignore"), this);
+    QAction *aIgnore = new QAction(i18n("&Ignore"), this);
     aIgnore->setToolTip(i18n("Ignores the changes on disk without any action."));
     aIgnore->setIcon(KStandardGuiItem::overwrite().icon());
     m_message->addAction(aIgnore);
@@ -1367,10 +1378,9 @@ void KateModOnHdPrompt::slotDiff()
     // Start a KProcess that creates a diff
     m_proc = new KProcess(this);
     m_proc->setOutputChannelMode(KProcess::MergedChannels);
-    *m_proc << QStringLiteral("diff") << QLatin1String("-u")
-            << QStringLiteral("-") <<  m_doc->url().toLocalFile();
+    *m_proc << QStringLiteral("diff") << QStringLiteral("-u") << QStringLiteral("-") << m_doc->url().toLocalFile();
     connect(m_proc, SIGNAL(readyRead()), this, SLOT(slotDataAvailable()));
-    connect(m_proc, SIGNAL(finished(int,QProcess::ExitStatus)), this, SLOT(slotPDone()));
+    connect(m_proc, SIGNAL(finished(int, QProcess::ExitStatus)), this, SLOT(slotPDone()));
 
     // disable the diff button, to hinder the user to run it twice.
     m_diffAction->setEnabled(false);
@@ -1411,9 +1421,7 @@ void KateModOnHdPrompt::slotPDone()
     }
 
     if (m_diffFile->size() == 0) {
-        KMessageBox::information(nullptr,
-                                 i18n("The files are identical."),
-                                 i18n("Diff Output"));
+        KMessageBox::information(nullptr, i18n("The files are identical."), i18n("Diff Output"));
         delete m_diffFile;
         m_diffFile = nullptr;
         return;
@@ -1428,5 +1436,4 @@ void KateModOnHdPrompt::slotPDone()
     KRun::runUrl(url, QStringLiteral("text/x-patch"), nullptr, KRun::RunFlags(KRun::DeleteTemporaryFiles));
 }
 
-//END KateModOnHdPrompt
-
+// END KateModOnHdPrompt
