@@ -1,39 +1,38 @@
-/* This file is part of the KDE project
- *
- *  Copyright (C) 2010 Christoph Cullmann <cullmann@kde.org>
- *
- *  Based on code of the SmartCursor/Range by:
- *  Copyright (C) 2003-2005 Hamish Rodda <rodda@kde.org>
- *
- *  This library is free software; you can redistribute it and/or
- *  modify it under the terms of the GNU Library General Public
- *  License as published by the Free Software Foundation; either
- *  version 2 of the License, or (at your option) any later version.
- *
- *  This library is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- *  Library General Public License for more details.
- *
- *  You should have received a copy of the GNU Library General Public License
- *  along with this library; see the file COPYING.LIB.  If not, write to
- *  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- *  Boston, MA 02110-1301, USA.
- */
+/*  SPDX-License-Identifier: LGPL-2.0-or-later
+
+    Copyright (C) 2010 Christoph Cullmann <cullmann@kde.org>
+
+    Based on code of the SmartCursor/Range by:
+    Copyright (C) 2003-2005 Hamish Rodda <rodda@kde.org>
+
+    This library is free software; you can redistribute it and/or
+    modify it under the terms of the GNU Library General Public
+    License as published by the Free Software Foundation; either
+    version 2 of the License, or (at your option) any later version.
+
+    This library is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+    Library General Public License for more details.
+
+    You should have received a copy of the GNU Library General Public License
+    along with this library; see the file COPYING.LIB.  If not, write to
+    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+    Boston, MA 02110-1301, USA.
+*/
 
 #ifndef KTEXTEDITOR_MOVINGRANGE_H
 #define KTEXTEDITOR_MOVINGRANGE_H
 
-#include <ktexteditor_export.h>
 #include <ktexteditor/attribute.h>
-#include <ktexteditor/range.h>
 #include <ktexteditor/movingcursor.h>
+#include <ktexteditor/range.h>
+#include <ktexteditor_export.h>
 
 #include <QDebug>
 
 namespace KTextEditor
 {
-
 class Document;
 class View;
 class MovingRangeFeedback;
@@ -174,8 +173,8 @@ public:
      * Behavior of range if it becomes empty.
      */
     enum EmptyBehavior {
-        AllowEmpty        = 0x0, ///< allow range to be empty
-        InvalidateIfEmpty = 0x1  ///< invalidate range, if it becomes empty
+        AllowEmpty = 0x0,       ///< allow range to be empty
+        InvalidateIfEmpty = 0x1 ///< invalidate range, if it becomes empty
     };
 
     //
@@ -344,7 +343,7 @@ private:
     /**
      * no assignment operator, no copying around clever ranges.
      */
-    MovingRange &operator= (const MovingRange &);
+    MovingRange &operator=(const MovingRange &);
 
     //
     // convenience API
@@ -364,7 +363,8 @@ public:
      * Convert this clever range into a dumb one.
      * @return normal range
      */
-    const Range toRange() const {
+    const Range toRange() const
+    {
         return Range(start().toCursor(), end().toCursor());
     }
 
@@ -372,7 +372,8 @@ public:
      * Convert this clever range into a dumb one. Equal to toRange, allowing to use implicit conversion.
      * @return normal range
      */
-    operator Range() const {
+    operator Range() const
+    {
         return Range(start().toCursor(), end().toCursor());
     }
 
@@ -382,7 +383,8 @@ public:
      * @param range range to print
      * @return debug stream
      */
-    inline friend QDebug operator<< (QDebug s, const MovingRange *range) {
+    inline friend QDebug operator<<(QDebug s, const MovingRange *range)
+    {
         if (range) {
             s << "[" << range->start() << " -> " << range->end() << "]";
         } else {
@@ -397,7 +399,8 @@ public:
      * @param range range to print
      * @return debug stream
      */
-    inline friend QDebug operator<< (QDebug s, const MovingRange &range) {
+    inline friend QDebug operator<<(QDebug s, const MovingRange &range)
+    {
         return s << &range;
     }
 
@@ -407,11 +410,12 @@ public:
      *
      * \returns \e true if the range contains no characters, otherwise \e false
      */
-    inline bool isEmpty() const {
+    inline bool isEmpty() const
+    {
         return start() == end();
     }
 
-    //BEGIN comparison functions
+    // BEGIN comparison functions
     /**
      * \name Comparison
      *
@@ -425,7 +429,8 @@ public:
      *
      * \return \e true, if this range contains \e range, otherwise \e false
      */
-    inline bool contains(const Range &range) const {
+    inline bool contains(const Range &range) const
+    {
         return range.start() >= start() && range.end() <= end();
     }
 
@@ -436,7 +441,8 @@ public:
      *
      * \return \e true if the cursor is contained within this range, otherwise \e false.
      */
-    inline bool contains(const Cursor &cursor) const {
+    inline bool contains(const Cursor &cursor) const
+    {
         return cursor >= start() && cursor < end();
     }
 
@@ -447,7 +453,8 @@ public:
      *
      * \return \e true if the line is wholly encompassed by this range, otherwise \e false.
      */
-    inline bool containsLine(int line) const {
+    inline bool containsLine(int line) const
+    {
         return (line > start().line() || (line == start().line() && !start().column())) && line < end().line();
     }
 
@@ -458,7 +465,8 @@ public:
      *
      * \return \e true if the range contains \e column, otherwise \e false
      */
-    inline bool containsColumn(int column) const {
+    inline bool containsColumn(int column) const
+    {
         return column >= start().column() && column < end().column();
     }
 
@@ -478,7 +486,8 @@ public:
      *
      * \return \e true, if the range overlaps at least part of \e line, otherwise \e false
      */
-    inline bool overlapsLine(int line) const {
+    inline bool overlapsLine(int line) const
+    {
         return line >= start().line() && line <= end().line();
     }
 
@@ -492,7 +501,8 @@ public:
      * \return \e true if the column is between the range's starting and ending
      *         columns, otherwise \e false.
      */
-    inline bool overlapsColumn(int column) const {
+    inline bool overlapsColumn(int column) const
+    {
         return start().column() <= column && end().column() > column;
     }
 
@@ -503,7 +513,8 @@ public:
      * \return \e true if both the start and end positions are on the same
      *         line, otherwise \e false
      */
-    inline bool onSingleLine() const {
+    inline bool onSingleLine() const
+    {
         return start().line() == end().line();
     }
 
@@ -513,11 +524,12 @@ public:
      * \return the number of lines separating the start() and end() positions;
      *         0 if the start and end lines are the same.
      */
-    inline int numberOfLines() const Q_DECL_NOEXCEPT {
+    inline int numberOfLines() const Q_DECL_NOEXCEPT
+    {
         return end().line() - start().line();
     }
 
-    //END comparison functions
+    // END comparison functions
 };
 
 Q_DECLARE_OPERATORS_FOR_FLAGS(MovingRange::InsertBehaviors)
@@ -525,4 +537,3 @@ Q_DECLARE_OPERATORS_FOR_FLAGS(MovingRange::InsertBehaviors)
 }
 
 #endif
-
