@@ -1,25 +1,25 @@
-/* This file is part of the KDE project
- *
- *  Copyright (C) 2010 Christoph Cullmann <cullmann@kde.org>
- *
- *  Based on code of the SmartCursor/Range by:
- *  Copyright (C) 2003-2005 Hamish Rodda <rodda@kde.org>
- *
- *  This library is free software; you can redistribute it and/or
- *  modify it under the terms of the GNU Library General Public
- *  License as published by the Free Software Foundation; either
- *  version 2 of the License, or (at your option) any later version.
- *
- *  This library is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- *  Library General Public License for more details.
- *
- *  You should have received a copy of the GNU Library General Public License
- *  along with this library; see the file COPYING.LIB.  If not, write to
- *  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- *  Boston, MA 02110-1301, USA.
- */
+/*  SPDX-License-Identifier: LGPL-2.0-or-later
+
+    Copyright (C) 2010 Christoph Cullmann <cullmann@kde.org>
+
+    Based on code of the SmartCursor/Range by:
+    Copyright (C) 2003-2005 Hamish Rodda <rodda@kde.org>
+
+    This library is free software; you can redistribute it and/or
+    modify it under the terms of the GNU Library General Public
+    License as published by the Free Software Foundation; either
+    version 2 of the License, or (at your option) any later version.
+
+    This library is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+    Library General Public License for more details.
+
+    You should have received a copy of the GNU Library General Public License
+    along with this library; see the file COPYING.LIB.  If not, write to
+    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+    Boston, MA 02110-1301, USA.
+*/
 
 #ifndef KTEXTEDITOR_MOVINGRANGEFEEDBACK_H
 #define KTEXTEDITOR_MOVINGRANGEFEEDBACK_H
@@ -28,7 +28,6 @@
 
 namespace KTextEditor
 {
-
 class View;
 class MovingRange;
 
@@ -117,4 +116,3 @@ private:
 }
 
 #endif
-
