@@ -1,48 +1,48 @@
-/*  This file is part of the KDE libraries and the Kate part.
- *
- *  Copyright (C) 2001-2010 Christoph Cullmann <cullmann@kde.org>
- *
- *  This library is free software; you can redistribute it and/or
- *  modify it under the terms of the GNU Library General Public
- *  License as published by the Free Software Foundation; either
- *  version 2 of the License, or (at your option) any later version.
- *
- *  This library is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- *  Library General Public License for more details.
- *
- *  You should have received a copy of the GNU Library General Public License
- *  along with this library; see the file COPYING.LIB.  If not, write to
- *  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- *  Boston, MA 02110-1301, USA.
- */
+/*  SPDX-License-Identifier: LGPL-2.0-or-later
 
-//BEGIN Includes
+    Copyright (C) 2001-2010 Christoph Cullmann <cullmann@kde.org>
+
+    This library is free software; you can redistribute it and/or
+    modify it under the terms of the GNU Library General Public
+    License as published by the Free Software Foundation; either
+    version 2 of the License, or (at your option) any later version.
+
+    This library is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+    Library General Public License for more details.
+
+    You should have received a copy of the GNU Library General Public License
+    along with this library; see the file COPYING.LIB.  If not, write to
+    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+    Boston, MA 02110-1301, USA.
+*/
+
+// BEGIN Includes
 #include "katemodeconfigpage.h"
 
-#include "katedocument.h"
-#include "kateconfig.h"
-#include "kateview.h"
-#include "kateglobal.h"
 #include "kateautoindent.h"
+#include "kateconfig.h"
+#include "katedocument.h"
+#include "kateglobal.h"
 #include "katesyntaxmanager.h"
+#include "kateview.h"
 
 #include "ui_filetypeconfigwidget.h"
 
-#include <KMimeTypeChooser>
 #include "katepartdebug.h"
+#include <KMimeTypeChooser>
 
-#include <QRegularExpression>
 #include <QCheckBox>
 #include <QComboBox>
 #include <QGroupBox>
 #include <QLabel>
 #include <QLayout>
 #include <QPushButton>
-#include <QToolButton>
+#include <QRegularExpression>
 #include <QSpinBox>
-//END Includes
+#include <QToolButton>
+// END Includes
 
 ModeConfigPage::ModeConfigPage(QWidget *parent)
     : KateConfigPage(parent)
@@ -58,9 +58,10 @@ ModeConfigPage::ModeConfigPage(QWidget *parent)
     ui->setupUi(newWidget);
 
     ui->cmbHl->addItem(i18n("<Unchanged>"), QVariant(QString()));
-   for (const auto &hl : KateHlManager::self()->modeList()) {
-        if (hl.section().length() > 0)
-            ui->cmbHl->addItem(hl.section() + QLatin1Char('/') + hl.translatedName(), QVariant(hl.name()));
+    for (const auto &hl : KateHlManager::self()->modeList()) {
+        const auto section = hl.translatedSection();
+        if (!section.isEmpty())
+            ui->cmbHl->addItem(section + QLatin1Char('/') + hl.translatedName(), QVariant(hl.name()));
         else {
             ui->cmbHl->addItem(hl.translatedName(), QVariant(hl.name()));
         }
@@ -118,7 +119,9 @@ void ModeConfigPage::reload()
     m_types.clear();
 
     // deep copy...
-    foreach (KateFileType *type, KTextEditor::EditorPrivate::self()->modeManager()->list()) {
+    const QList<KateFileType *> &modeList = KTextEditor::EditorPrivate::self()->modeManager()->list();
+    m_types.reserve(modeList.size());
+    for (KateFileType *type : modeList) {
         KateFileType *t = new KateFileType();
         *t = *type;
         m_types.append(t);
@@ -143,7 +146,7 @@ void ModeConfigPage::update()
 
     ui->cmbFiletypes->clear();
 
-    foreach (KateFileType *type, m_types) {
+    for (KateFileType *type : qAsConst(m_types)) {
         if (!type->sectionTranslated().isEmpty()) {
             ui->cmbFiletypes->addItem(type->sectionTranslated() + QLatin1Char('/') + type->nameTranslated());
         } else {
@@ -236,7 +239,7 @@ void ModeConfigPage::typeChanged(int type)
     if (type > -1 && type < m_types.count()) {
         KateFileType *t = m_types.at(type);
 
-        ui->gbProperties->setTitle(i18n("Properties of %1",  ui->cmbFiletypes->currentText()));
+        ui->gbProperties->setTitle(i18n("Properties of %1", ui->cmbFiletypes->currentText()));
 
         ui->gbProperties->setEnabled(true);
         ui->btnDelete->setEnabled(true);
