@@ -1,38 +1,39 @@
-/*  This file is part of the KDE libraries and the Kate part.
- *
- *  Copyright (C) 2001-2010 Christoph Cullmann <cullmann@kde.org>
- *
- *  This library is free software; you can redistribute it and/or
- *  modify it under the terms of the GNU Library General Public
- *  License as published by the Free Software Foundation; either
- *  version 2 of the License, or (at your option) any later version.
- *
- *  This library is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- *  Library General Public License for more details.
- *
- *  You should have received a copy of the GNU Library General Public License
- *  along with this library; see the file COPYING.LIB.  If not, write to
- *  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- *  Boston, MA 02110-1301, USA.
- */
+/*  SPDX-License-Identifier: LGPL-2.0-or-later
 
-//BEGIN Includes
+    Copyright (C) 2001-2010 Christoph Cullmann <cullmann@kde.org>
+
+    This library is free software; you can redistribute it and/or
+    modify it under the terms of the GNU Library General Public
+    License as published by the Free Software Foundation; either
+    version 2 of the License, or (at your option) any later version.
+
+    This library is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+    Library General Public License for more details.
+
+    You should have received a copy of the GNU Library General Public License
+    along with this library; see the file COPYING.LIB.  If not, write to
+    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+    Boston, MA 02110-1301, USA.
+*/
+
+// BEGIN Includes
 #include "katemodemanager.h"
 #include "katewildcardmatcher.h"
+#include "katestatusbar.h"
 
-#include "katedocument.h"
 #include "kateconfig.h"
-#include "kateview.h"
+#include "katedocument.h"
 #include "kateglobal.h"
-#include "katesyntaxmanager.h"
 #include "katepartdebug.h"
+#include "katesyntaxmanager.h"
+#include "kateview.h"
 
 #include <KConfigGroup>
 
 #include <QMimeDatabase>
-//END Includes
+// END Includes
 
 static QStringList vectorToList(const QVector<QString> &v)
 {
@@ -70,6 +71,7 @@ void KateModeManager::update()
 
     QStringList g(config.groupList());
 
+    KateFileType *normalType = nullptr;
     qDeleteAll(m_types);
     m_types.clear();
     m_name2Type.clear();
@@ -79,7 +81,6 @@ void KateModeManager::update()
         KateFileType *type = new KateFileType();
         type->number = z;
         type->name = g[z];
-        type->section = cg.readEntry(QStringLiteral("Section"));
         type->wildcards = cg.readXdgListEntry(QStringLiteral("Wildcards"));
         type->mimetypes = cg.readXdgListEntry(QStringLiteral("Mimetypes"));
         type->priority = cg.readEntry(QStringLiteral("Priority"), 0);
@@ -90,19 +91,34 @@ void KateModeManager::update()
 
         // only for generated types...
         type->hlGenerated = cg.readEntry(QStringLiteral("Highlighting Generated"), false);
-        type->version = cg.readEntry(QStringLiteral("Highlighting Version"));
 
-        // insert into the list + hash...
-        m_types.append(type);
+        // the "Normal" mode will be added later
+        if (type->name == QLatin1String("Normal")) {
+            if (!normalType) {
+                normalType = type;
+            }
+        } else {
+            type->section = cg.readEntry(QStringLiteral("Section"));
+            type->version = cg.readEntry(QStringLiteral("Highlighting Version"));
+        }
+
+        // insert into the hash...
+        // NOTE: "katemoderc" could have modes that do not exist or are invalid (for example, custom
+        // XML files that were deleted or renamed), so they will be added to the list "m_types" later
         m_name2Type.insert(type->name, type);
     }
 
     // try if the hl stuff is up to date...
     const auto modes = KateHlManager::self()->modeList();
     for (int i = 0; i < modes.size(); ++i) {
-        // filter out hidden languages; and
-        // filter out "None" hl, we add that later as "normal" mode
-        if (modes[i].isHidden() || modes[i].name() == QLatin1String("None")) {
+        /**
+         * filter out hidden languages; and
+         * filter out "None" hl, we add that later as "Normal" mode.
+         * Hl with empty names will also be filtered. The
+         * KTextEditor::DocumentPrivate::updateFileType() function considers
+         * hl with empty names as invalid.
+         */
+        if (modes[i].isHidden() || modes[i].name().isEmpty() || modes[i].name() == QLatin1String("None")) {
             continue;
         }
 
@@ -115,9 +131,10 @@ void KateModeManager::update()
             type = new KateFileType();
             type->name = modes[i].name();
             type->priority = 0;
-            m_types.append(type);
             m_name2Type.insert(type->name, type);
         }
+        // only the types that exist or are valid are added
+        m_types.append(type);
 
         if (newType || type->version != QString::number(modes[i].version())) {
             type->name = modes[i].name();
@@ -139,15 +156,25 @@ void KateModeManager::update()
     std::sort(m_types.begin(), m_types.end(), compareKateFileType);
 
     // add the none type...
-    KateFileType *t = new KateFileType();
+    if (!normalType) {
+        normalType = new KateFileType();
+    }
 
     // marked by hlGenerated
-    t->name = QStringLiteral("Normal");
-    t->translatedName = i18n("Normal");
-    t->hl = QStringLiteral("None");
-    t->hlGenerated = true;
+    normalType->name = QStringLiteral("Normal");
+    normalType->translatedName = i18n("Normal");
+    normalType->hl = QStringLiteral("None");
+    normalType->hlGenerated = true;
 
-    m_types.prepend(t);
+    m_types.prepend(normalType);
+
+    // update the mode menu of the status bar, for all views.
+    // this menu uses the KateFileType objects
+    for (auto *view : KTextEditor::EditorPrivate::self()->views()) {
+        if (view->statusBar() && view->statusBar()->modeMenu()) {
+            view->statusBar()->modeMenu()->reloadItems();
+        }
+    }
 }
 
 //
@@ -158,7 +185,8 @@ void KateModeManager::save(const QList<KateFileType *> &v)
     KConfig katerc(QStringLiteral("katemoderc"), KConfig::NoGlobals);
 
     QStringList newg;
-    foreach (const KateFileType *type, v) {
+    newg.reserve(v.size());
+    for (const KateFileType *type : v) {
         KConfigGroup config(&katerc, type->name);
 
         config.writeEntry("Section", type->section);
@@ -168,7 +196,7 @@ void KateModeManager::save(const QList<KateFileType *> &v)
         config.writeEntry("Indenter", type->indenter);
 
         QString varLine = type->varLine;
-        if (!varLine.contains(QStringLiteral("kate:"))) {
+        if (!varLine.contains(QLatin1String("kate:"))) {
             varLine.prepend(QLatin1String("kate: "));
         }
 
@@ -183,7 +211,8 @@ void KateModeManager::save(const QList<KateFileType *> &v)
         newg << type->name;
     }
 
-    foreach (const QString &groupName, katerc.groupList()) {
+    const auto groupNames = katerc.groupList();
+    for (const QString &groupName : groupNames) {
         if (newg.indexOf(groupName) == -1) {
             katerc.deleteGroup(groupName);
         }
@@ -210,8 +239,14 @@ QString KateModeManager::fileType(KTextEditor::DocumentPrivate *doc, const QStri
     QString result;
 
     // Try wildcards
-    if (! fileName.isEmpty()) {
-        static const QStringList commonSuffixes = QStringLiteral(".orig;.new;~;.bak;.BAK").split(QLatin1Char(';'));
+    if (!fileName.isEmpty()) {
+        static const QLatin1String commonSuffixes[] = {
+            QLatin1String(".orig"),
+            QLatin1String(".new"),
+            QLatin1String("~"),
+            QLatin1String(".bak"),
+            QLatin1String(".BAK"),
+        };
 
         if (!(result = wildcardsFind(fileName)).isEmpty()) {
             return result;
@@ -224,16 +259,15 @@ QString KateModeManager::fileType(KTextEditor::DocumentPrivate *doc, const QStri
             }
         }
 
-        for (QStringList::ConstIterator it = commonSuffixes.begin(); it != commonSuffixes.end(); ++it) {
-            if (*it != backupSuffix && fileName.endsWith(*it)) {
-                if (!(result = wildcardsFind(fileName.left(length - (*it).length()))).isEmpty()) {
+        for (auto &commonSuffix : commonSuffixes) {
+            if (commonSuffix != backupSuffix && fileName.endsWith(commonSuffix)) {
+                if (!(result = wildcardsFind(fileName.left(length - commonSuffix.size()))).isEmpty()) {
                     return result;
                 }
             }
         }
     }
 
-
     // either read the file passed to this function (pre-load) or use the normal mimeType() KF KTextEditor API
     QString mtName;
     if (!fileToReadFrom.isEmpty()) {
@@ -243,7 +277,7 @@ QString KateModeManager::fileType(KTextEditor::DocumentPrivate *doc, const QStri
     }
 
     QList<KateFileType *> types;
-    foreach (KateFileType *type, m_types) {
+    for (KateFileType *type : qAsConst(m_types)) {
         if (type->mimetypes.indexOf(mtName) > -1) {
             types.append(type);
         }
@@ -253,7 +287,7 @@ QString KateModeManager::fileType(KTextEditor::DocumentPrivate *doc, const QStri
         int pri = -1;
         QString name;
 
-        foreach (KateFileType *type, types) {
+        for (KateFileType *type : qAsConst(types)) {
             if (type->priority > pri) {
                 pri = type->priority;
                 name = type->name;
@@ -270,12 +304,12 @@ QString KateModeManager::wildcardsFind(const QString &fileName)
 {
     KateFileType *match = nullptr;
     int minPrio = -1;
-    foreach (KateFileType *type, m_types) {
+    for (KateFileType *type : qAsConst(m_types)) {
         if (type->priority <= minPrio) {
             continue;
         }
 
-        foreach (const QString &wildcard, type->wildcards) {
+        for (const QString &wildcard : qAsConst(type->wildcards)) {
             if (KateWildcardMatcher::exactMatch(fileName, wildcard)) {
                 match = type;
                 minPrio = type->priority;
@@ -297,4 +331,3 @@ const KateFileType &KateModeManager::fileType(const QString &name) const
     static KateFileType notype;
     return notype;
 }
-
