@@ -1,50 +1,51 @@
-/* This file is part of the KDE libraries
-   Copyright (C) 2007, 2008 Matthew Woehlke <mw_triad@users.sourceforge.net>
-   Copyright (C) 2001-2003 Christoph Cullmann <cullmann@kde.org>
-   Copyright (C) 2002, 2003 Anders Lund <anders.lund@lund.tdcadsl.dk>
-   Copyright (C) 2012-2018 Dominik Haumann <dhaumann@kde.org>
- *
- *  This library is free software; you can redistribute it and/or
- *  modify it under the terms of the GNU Library General Public
- *  License as published by the Free Software Foundation; either
- *  version 2 of the License, or (at your option) any later version.
- *
- *  This library is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- *  Library General Public License for more details.
- *
- *  You should have received a copy of the GNU Library General Public License
- *  along with this library; see the file COPYING.LIB.  If not, write to
- *  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- *  Boston, MA 02110-1301, USA.
- */
+/*  SPDX-License-Identifier: LGPL-2.0-or-later
+
+    Copyright (C) 2007, 2008 Matthew Woehlke <mw_triad@users.sourceforge.net>
+    Copyright (C) 2001-2003 Christoph Cullmann <cullmann@kde.org>
+    Copyright (C) 2002, 2003 Anders Lund <anders.lund@lund.tdcadsl.dk>
+    Copyright (C) 2012-2018 Dominik Haumann <dhaumann@kde.org>
+
+    This library is free software; you can redistribute it and/or
+    modify it under the terms of the GNU Library General Public
+    License as published by the Free Software Foundation; either
+    version 2 of the License, or (at your option) any later version.
+
+    This library is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+    Library General Public License for more details.
+
+    You should have received a copy of the GNU Library General Public License
+    along with this library; see the file COPYING.LIB.  If not, write to
+    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+    Boston, MA 02110-1301, USA.
+*/
 
 // BEGIN Includes
 #include "kateschemaconfig.h"
 
-#include "katedocument.h"
-#include "kateschema.h"
-#include "kateconfig.h"
-#include "kateglobal.h"
-#include "kateview.h"
-#include "katerenderer.h"
-#include "katestyletreewidget.h"
 #include "katecolortreewidget.h"
-#include "katepartdebug.h"
+#include "kateconfig.h"
 #include "katedefaultcolors.h"
+#include "katedocument.h"
+#include "kateglobal.h"
+#include "katepartdebug.h"
+#include "katerenderer.h"
+#include "kateschema.h"
+#include "katestyletreewidget.h"
+#include "kateview.h"
 
 #include "ui_howtoimportschema.h"
 
-#include <KFontChooser>
-#include <KMessageBox>
 #include <KComboBox>
 #include <KConfigGroup>
+#include <KFontChooser>
+#include <KMessageBox>
 
 #include <QFileDialog>
 #include <QInputDialog>
-#include <QPushButton>
 #include <QProgressDialog>
+#include <QPushButton>
 #include <QTabWidget>
 
 // END
