@@ -1,55 +1,57 @@
-/* This file is part of the KDE libraries
-   Copyright (C) 2009-2010 Bernhard Beschow <bbeschow@cs.tu-berlin.de>
-   Copyright (C) 2007 Sebastian Pipping <webmaster@hartwork.org>
-   Copyright (C) 2007 Matthew Woehlke <mw_triad@users.sourceforge.net>
-   Copyright (C) 2007 Thomas Friedrichsmeier <thomas.friedrichsmeier@ruhr-uni-bochum.de>
+/*  SPDX-License-Identifier: LGPL-2.0-or-later
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License version 2 as published by the Free Software Foundation.
+    Copyright (C) 2009-2010 Bernhard Beschow <bbeschow@cs.tu-berlin.de>
+    Copyright (C) 2007 Sebastian Pipping <webmaster@hartwork.org>
+    Copyright (C) 2007 Matthew Woehlke <mw_triad@users.sourceforge.net>
+    Copyright (C) 2007 Thomas Friedrichsmeier <thomas.friedrichsmeier@ruhr-uni-bochum.de>
 
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
+    This library is free software; you can redistribute it and/or
+    modify it under the terms of the GNU Library General Public
+    License as published by the Free Software Foundation; either
+    version 2 of the License, or (at your option) any later version.
 
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+    This library is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+    Library General Public License for more details.
+
+    You should have received a copy of the GNU Library General Public License
+    along with this library; see the file COPYING.LIB.  If not, write to
+    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+    Boston, MA 02110-1301, USA.
 */
 
 #include "katesearchbar.h"
 
-#include "kateregexp.h"
-#include "katematch.h"
-#include "kateview.h"
-#include "katedocument.h"
-#include "kateundomanager.h"
 #include "kateconfig.h"
-#include "katerenderer.h"
+#include "katedocument.h"
 #include "kateglobal.h"
+#include "katematch.h"
+#include "kateregexp.h"
+#include "katerenderer.h"
+#include "kateundomanager.h"
+#include "kateview.h"
 
+#include <KTextEditor/DocumentCursor>
 #include <KTextEditor/Message>
 #include <KTextEditor/MovingRange>
-#include <KTextEditor/DocumentCursor>
 
 #include "ui_searchbarincremental.h"
 #include "ui_searchbarpower.h"
 
 #include <KColorScheme>
+#include <KLocalizedString>
 #include <KMessageBox>
 #include <KStandardAction>
-#include <KLocalizedString>
 
-#include <QVBoxLayout>
 #include <QCheckBox>
 #include <QComboBox>
 #include <QCompleter>
+#include <QElapsedTimer>
 #include <QRegularExpression>
 #include <QShortcut>
 #include <QStringListModel>
-#include <QTime>
+#include <QVBoxLayout>
 
 #include <vector>
 
@@ -57,19 +59,17 @@
 // #define FAST_DEBUG_ENABLE
 
 #ifdef FAST_DEBUG_ENABLE
-# define FAST_DEBUG(x) qCDebug(LOG_KTE) << x
+#define FAST_DEBUG(x) qCDebug(LOG_KTE) << x
 #else
-# define FAST_DEBUG(x)
+#define FAST_DEBUG(x)
 #endif
 
 using namespace KTextEditor;
 
 namespace
 {
-
 class AddMenuManager
 {
-
 private:
     QVector<QString> m_insertBefore;
     QVector<QString> m_insertAfter;
@@ -79,10 +79,10 @@ private:
 
 public:
     AddMenuManager(QMenu *parent, int expectedItemCount)
-        : m_insertBefore(QVector<QString>(expectedItemCount)),
-          m_insertAfter(QVector<QString>(expectedItemCount)),
-          m_indexWalker(0),
-          m_menu(nullptr)
+        : m_insertBefore(QVector<QString>(expectedItemCount))
+        , m_insertAfter(QVector<QString>(expectedItemCount))
+        , m_indexWalker(0)
+        , m_menu(nullptr)
     {
         Q_ASSERT(parent != nullptr);
         m_menu = parent->addMenu(i18n("Add..."));
@@ -100,9 +100,7 @@ public:
         m_menu->setEnabled(enabled);
     }
 
-    void addEntry(const QString &before, const QString after,
-                  const QString description, const QString &realBefore = QString(),
-                  const QString &realAfter = QString())
+    void addEntry(const QString &before, const QString &after, const QString &description, const QString &realBefore = QString(), const QString &realAfter = QString())
     {
         if (m_menu == nullptr) {
             return;
@@ -141,25 +139,24 @@ public:
 } // anon namespace
 
 KateSearchBar::KateSearchBar(bool initAsPower, KTextEditor::ViewPrivate *view, KateViewConfig *config)
-    : KateViewBarWidget(true, view),
-      m_view(view),
-      m_config(config),
-      m_layout(new QVBoxLayout()),
-      m_widget(nullptr),
-      m_incUi(nullptr),
-      m_incInitCursor(view->cursorPosition()),
-      m_powerUi(nullptr),
-      highlightMatchAttribute(new Attribute()),
-      highlightReplacementAttribute(new Attribute()),
-      m_incHighlightAll(false),
-      m_incFromCursor(true),
-      m_incMatchCase(false),
-      m_powerMatchCase(true),
-      m_powerFromCursor(false),
-      m_powerHighlightAll(false),
-      m_powerMode(0)
+    : KateViewBarWidget(true, view)
+    , m_view(view)
+    , m_config(config)
+    , m_layout(new QVBoxLayout())
+    , m_widget(nullptr)
+    , m_incUi(nullptr)
+    , m_incInitCursor(view->cursorPosition())
+    , m_powerUi(nullptr)
+    , highlightMatchAttribute(new Attribute())
+    , highlightReplacementAttribute(new Attribute())
+    , m_incHighlightAll(false)
+    , m_incFromCursor(true)
+    , m_incMatchCase(false)
+    , m_powerMatchCase(true)
+    , m_powerFromCursor(false)
+    , m_powerHighlightAll(false)
+    , m_powerMode(0)
 {
-
     connect(view, &KTextEditor::View::cursorPositionChanged, this, &KateSearchBar::updateIncInitCursor);
     connect(view, &KTextEditor::View::selectionChanged, this, &KateSearchBar::updateSelectionOnly);
     connect(this, &KateSearchBar::findOrReplaceAllFinished, this, &KateSearchBar::endFindOrReplaceAll);
@@ -192,12 +189,8 @@ KateSearchBar::KateSearchBar(bool initAsPower, KTextEditor::ViewPrivate *view, K
     m_powerFromCursor = (searchFlags & KateViewConfig::PowerFromCursor) != 0;
     m_powerHighlightAll = (searchFlags & KateViewConfig::PowerHighlightAll) != 0;
     m_powerMode = ((searchFlags & KateViewConfig::PowerModeRegularExpression) != 0)
-                  ? MODE_REGEX
-                  : (((searchFlags & KateViewConfig::PowerModeEscapeSequences) != 0)
-                     ? MODE_ESCAPE_SEQUENCES
-                     : (((searchFlags & KateViewConfig::PowerModeWholeWords) != 0)
-                        ? MODE_WHOLE_WORDS
-                        : MODE_PLAIN_TEXT));
+        ? MODE_REGEX
+        : (((searchFlags & KateViewConfig::PowerModeEscapeSequences) != 0) ? MODE_ESCAPE_SEQUENCES : (((searchFlags & KateViewConfig::PowerModeWholeWords) != 0) ? MODE_WHOLE_WORDS : MODE_PLAIN_TEXT));
 
     // Load one of either dialogs
     if (initAsPower) {
@@ -308,9 +301,7 @@ void KateSearchBar::showResultMessage()
 void KateSearchBar::showSearchWrappedHint(SearchDirection searchDirection)
 {
     // show message widget when wrapping
-    const QIcon icon = (searchDirection == SearchForward)
-        ? QIcon::fromTheme(QStringLiteral("go-down-search"))
-        : QIcon::fromTheme(QStringLiteral("go-up-search"));
+    const QIcon icon = (searchDirection == SearchForward) ? QIcon::fromTheme(QStringLiteral("go-down-search")) : QIcon::fromTheme(QStringLiteral("go-up-search"));
 
     if (!m_wrappedMessage || m_lastSearchDirection != searchDirection) {
         m_lastSearchDirection = searchDirection;
@@ -348,12 +339,11 @@ void KateSearchBar::highlightReplacement(const Range &range)
 
 void KateSearchBar::indicateMatch(MatchResult matchResult)
 {
-    QLineEdit *const lineEdit = isPower() ? m_powerUi->pattern->lineEdit()
-                                : m_incUi->pattern->lineEdit();
+    QLineEdit *const lineEdit = isPower() ? m_powerUi->pattern->lineEdit() : m_incUi->pattern->lineEdit();
     QPalette background(lineEdit->palette());
 
     switch (matchResult) {
-    case MatchFound:  // FALLTHROUGH
+    case MatchFound: // FALLTHROUGH
     case MatchWrappedForward:
     case MatchWrappedBackward:
         // Green background for line edit
@@ -445,13 +435,9 @@ void KateSearchBar::onIncPatternChanged(const QString &pattern)
         match.searchText(inputRange, pattern);
     }
 
-    const MatchResult matchResult = match.isValid()   ? (wrap ? MatchWrappedForward : MatchFound) :
-                                    pattern.isEmpty() ? MatchNothing :
-                                    MatchMismatch;
+    const MatchResult matchResult = match.isValid() ? (wrap ? MatchWrappedForward : MatchFound) : pattern.isEmpty() ? MatchNothing : MatchMismatch;
 
-    const Range selectionRange = pattern.isEmpty() ? Range(m_incInitCursor, m_incInitCursor) :
-                                 match.isValid()   ? match.range() :
-                                 Range::invalid();
+    const Range selectionRange = pattern.isEmpty() ? Range(m_incInitCursor, m_incInitCursor) : match.isValid() ? match.range() : Range::invalid();
 
     // don't update m_incInitCursor when we move the cursor
     disconnect(m_view, &KTextEditor::View::cursorPositionChanged, this, &KateSearchBar::updateIncInitCursor);
@@ -489,8 +475,7 @@ void KateSearchBar::onMatchCaseToggled(bool /*matchCase*/)
 
 bool KateSearchBar::matchCase() const
 {
-    return isPower() ? m_powerUi->matchCase->isChecked()
-           : m_incUi->matchCase->isChecked();
+    return isPower() ? m_powerUi->matchCase->isChecked() : m_incUi->matchCase->isChecked();
 }
 
 void KateSearchBar::fixForSingleLine(Range &range, SearchDirection searchDirection)
@@ -640,11 +625,8 @@ bool KateSearchBar::findOrReplace(SearchDirection searchDirection, const QString
     }
 
     if (askWrap) {
-        QString question = searchDirection == SearchForward  ? i18n("Bottom of file reached. Continue from top?")
-                           : i18n("Top of file reached. Continue from bottom?");
-        wrap = (KMessageBox::questionYesNo(nullptr, question, i18n("Continue search?"), KStandardGuiItem::yes(), KStandardGuiItem::no(),
-                                           QStringLiteral("DoNotShowAgainContinueSearchDialog")) == KMessageBox::Yes);
-
+        QString question = searchDirection == SearchForward ? i18n("Bottom of file reached. Continue from top?") : i18n("Top of file reached. Continue from bottom?");
+        wrap = (KMessageBox::questionYesNo(nullptr, question, i18n("Continue search?"), KStandardGuiItem::yes(), KStandardGuiItem::no(), QStringLiteral("DoNotShowAgainContinueSearchDialog")) == KMessageBox::Yes);
     }
     if (wrap) {
         showSearchWrappedHint(searchDirection);
@@ -656,10 +638,7 @@ bool KateSearchBar::findOrReplace(SearchDirection searchDirection, const QString
         selectRange2(match.range());
     }
 
-    const MatchResult matchResult = !match.isValid()                 ? MatchMismatch :
-                                    !wrap                            ? MatchFound :
-                                    searchDirection == SearchForward ? MatchWrappedForward :
-                                    MatchWrappedBackward;
+    const MatchResult matchResult = !match.isValid() ? MatchMismatch : !wrap ? MatchFound : searchDirection == SearchForward ? MatchWrappedForward : MatchWrappedBackward;
     indicateMatch(matchResult);
 
     // highlight replacements if applicable
@@ -678,9 +657,7 @@ void KateSearchBar::findAll()
     // clear highlightings of prior search&replace action
     clearHighlights();
 
-    Range inputRange = (m_view->selection() && selectionOnly())
-                       ? m_view->selectionRange()
-                       : m_view->document()->documentRange();
+    Range inputRange = (m_view->selection() && selectionOnly()) ? m_view->selectionRange() : m_view->document()->documentRange();
 
     beginFindAll(inputRange);
 }
@@ -697,9 +674,7 @@ bool KateSearchBar::isPatternValid() const
         return false;
     }
 
-    return searchOptions().testFlag(WholeWords) ? searchPattern().trimmed() == searchPattern() :
-           searchOptions().testFlag(Regex)      ? QRegularExpression(searchPattern()).isValid() :
-           true;
+    return searchOptions().testFlag(WholeWords) ? searchPattern().trimmed() == searchPattern() : searchOptions().testFlag(Regex) ? QRegularExpression(searchPattern()).isValid() : true;
 }
 
 void KateSearchBar::givePatternFeedback()
@@ -749,41 +724,23 @@ void KateSearchBar::sendConfig()
         backupConfig(OF_POWER);
 
         // Update power search flags only
-        const auto incFlagsOnly = pastFlags
-                                  & (KateViewConfig::IncHighlightAll
-                                     | KateViewConfig::IncFromCursor
-                                     | KateViewConfig::IncMatchCase);
+        const auto incFlagsOnly = pastFlags & (KateViewConfig::IncHighlightAll | KateViewConfig::IncFromCursor | KateViewConfig::IncMatchCase);
 
-        futureFlags = incFlagsOnly
-                      | (m_powerMatchCase ? KateViewConfig::PowerMatchCase : 0)
-                      | (m_powerFromCursor ? KateViewConfig::PowerFromCursor : 0)
-                      | (m_powerHighlightAll ? KateViewConfig::PowerHighlightAll : 0)
-                      | ((m_powerMode == MODE_REGEX)
-                         ? KateViewConfig::PowerModeRegularExpression
-                         : ((m_powerMode == MODE_ESCAPE_SEQUENCES)
-                            ? KateViewConfig::PowerModeEscapeSequences
-                            : ((m_powerMode == MODE_WHOLE_WORDS)
-                               ? KateViewConfig::PowerModeWholeWords
-                               : KateViewConfig::PowerModePlainText)));
+        futureFlags = incFlagsOnly | (m_powerMatchCase ? KateViewConfig::PowerMatchCase : 0) | (m_powerFromCursor ? KateViewConfig::PowerFromCursor : 0) | (m_powerHighlightAll ? KateViewConfig::PowerHighlightAll : 0) |
+            ((m_powerMode == MODE_REGEX)
+                 ? KateViewConfig::PowerModeRegularExpression
+                 : ((m_powerMode == MODE_ESCAPE_SEQUENCES) ? KateViewConfig::PowerModeEscapeSequences : ((m_powerMode == MODE_WHOLE_WORDS) ? KateViewConfig::PowerModeWholeWords : KateViewConfig::PowerModePlainText)));
 
     } else if (m_incUi != nullptr) {
         const bool OF_INCREMENTAL = false;
         backupConfig(OF_INCREMENTAL);
 
         // Update incremental search flags only
-        const auto powerFlagsOnly = pastFlags
-                                    & (KateViewConfig::PowerMatchCase
-                                       | KateViewConfig::PowerFromCursor
-                                       | KateViewConfig::PowerHighlightAll
-                                       | KateViewConfig::PowerModeRegularExpression
-                                       | KateViewConfig::PowerModeEscapeSequences
-                                       | KateViewConfig::PowerModeWholeWords
-                                       | KateViewConfig::PowerModePlainText);
+        const auto powerFlagsOnly = pastFlags &
+            (KateViewConfig::PowerMatchCase | KateViewConfig::PowerFromCursor | KateViewConfig::PowerHighlightAll | KateViewConfig::PowerModeRegularExpression | KateViewConfig::PowerModeEscapeSequences |
+             KateViewConfig::PowerModeWholeWords | KateViewConfig::PowerModePlainText);
 
-        futureFlags = powerFlagsOnly
-                      | (m_incHighlightAll ? KateViewConfig::IncHighlightAll : 0)
-                      | (m_incFromCursor ? KateViewConfig::IncFromCursor : 0)
-                      | (m_incMatchCase ? KateViewConfig::IncMatchCase : 0);
+        futureFlags = powerFlagsOnly | (m_incHighlightAll ? KateViewConfig::IncHighlightAll : 0) | (m_incFromCursor ? KateViewConfig::IncFromCursor : 0) | (m_incMatchCase ? KateViewConfig::IncMatchCase : 0);
     }
 
     // Adjust global config
@@ -808,7 +765,7 @@ void KateSearchBar::replaceNext()
 
 // replacement == NULL --> Only highlight all matches
 // replacement != NULL --> Replace and highlight all matches
-void KateSearchBar::beginFindOrReplaceAll(Range inputRange, const QString &replacement, bool replaceMode/* = true*/)
+void KateSearchBar::beginFindOrReplaceAll(Range inputRange, const QString &replacement, bool replaceMode /* = true*/)
 {
     // don't let selectionChanged signal mess around in this routine
     disconnect(m_view, &KTextEditor::View::selectionChanged, this, &KateSearchBar::updateSelectionOnly);
@@ -816,11 +773,11 @@ void KateSearchBar::beginFindOrReplaceAll(Range inputRange, const QString &repla
     connect(m_view->doc(), &KTextEditor::Document::aboutToClose, this, &KateSearchBar::endFindOrReplaceAll);
 
     if (m_powerUi) {
-    // Offer Cancel button and disable not useful buttons
-    m_powerUi->searchCancelStacked->setCurrentIndex(m_powerUi->searchCancelStacked->indexOf(m_powerUi->cancelPage));
-    m_powerUi->findNext->setEnabled(false);
-    m_powerUi->findPrev->setEnabled(false);
-    m_powerUi->replaceNext->setEnabled(false);
+        // Offer Cancel button and disable not useful buttons
+        m_powerUi->searchCancelStacked->setCurrentIndex(m_powerUi->searchCancelStacked->indexOf(m_powerUi->cancelPage));
+        m_powerUi->findNext->setEnabled(false);
+        m_powerUi->findPrev->setEnabled(false);
+        m_powerUi->replaceNext->setEnabled(false);
     }
 
     m_highlightRanges.clear();
@@ -852,7 +809,7 @@ void KateSearchBar::findOrReplaceAll()
 
     int line = m_inputRange.start().line();
 
-    QTime rolex; // Watchog to suspend the work after some time
+    QElapsedTimer rolex; // Watchog to suspend the work after some time
     rolex.start();
     bool timeOut = false;
     bool done = false;
@@ -946,10 +903,10 @@ void KateSearchBar::endFindOrReplaceAll()
 
     // Add ScrollBarMarks
     if (!m_highlightRanges.empty()) {
-        KTextEditor::MarkInterface* iface = qobject_cast<KTextEditor::MarkInterface*>(m_view->document());
+        KTextEditor::MarkInterface *iface = qobject_cast<KTextEditor::MarkInterface *>(m_view->document());
         if (iface) {
             iface->setMarkDescription(KTextEditor::MarkInterface::SearchMatch, i18n("SearchHighLight"));
-            iface->setMarkPixmap(KTextEditor::MarkInterface::SearchMatch, QIcon().pixmap(0,0));
+            iface->setMarkPixmap(KTextEditor::MarkInterface::SearchMatch, QIcon().pixmap(0, 0));
             for (const Range &r : m_highlightRanges) {
                 iface->addMark(r.start().line(), KTextEditor::MarkInterface::SearchMatch);
             }
@@ -968,7 +925,7 @@ void KateSearchBar::endFindOrReplaceAll()
         for (const Range &r : qAsConst(m_highlightRanges)) {
             highlightMatch(r);
         }
-//         indicateMatch(m_matchCounter > 0 ? MatchFound : MatchMismatch); TODO
+        //         indicateMatch(m_matchCounter > 0 ? MatchFound : MatchMismatch); TODO
     }
 
     // Clean-Up the still hold MovingRange
@@ -978,17 +935,17 @@ void KateSearchBar::endFindOrReplaceAll()
     connect(m_view, &KTextEditor::View::selectionChanged, this, &KateSearchBar::updateSelectionOnly);
 
     if (m_powerUi) {
-    // Offer Find and Replace buttons and enable again useful buttons
-    m_powerUi->searchCancelStacked->setCurrentIndex(m_powerUi->searchCancelStacked->indexOf(m_powerUi->searchPage));
-    m_powerUi->findNext->setEnabled(true);
-    m_powerUi->findPrev->setEnabled(true);
-    m_powerUi->replaceNext->setEnabled(true);
+        // Offer Find and Replace buttons and enable again useful buttons
+        m_powerUi->searchCancelStacked->setCurrentIndex(m_powerUi->searchCancelStacked->indexOf(m_powerUi->searchPage));
+        m_powerUi->findNext->setEnabled(true);
+        m_powerUi->findPrev->setEnabled(true);
+        m_powerUi->replaceNext->setEnabled(true);
 
-    // Add to search history
-    addCurrentTextToHistory(m_powerUi->pattern);
+        // Add to search history
+        addCurrentTextToHistory(m_powerUi->pattern);
 
-    // Add to replace history
-    addCurrentTextToHistory(m_powerUi->replacement);
+        // Add to replace history
+        addCurrentTextToHistory(m_powerUi->replacement);
     }
 
     m_cancelFindOrReplace = true; // Indicate we are not running
@@ -1004,9 +961,7 @@ void KateSearchBar::replaceAll()
 
     // Where to replace?
     const bool selected = m_view->selection();
-    Range inputRange = (selected && selectionOnly())
-                       ? m_view->selectionRange()
-                       : m_view->document()->documentRange();
+    Range inputRange = (selected && selectionOnly()) ? m_view->selectionRange() : m_view->document()->documentRange();
 
     beginFindOrReplaceAll(inputRange, replacement);
 }
@@ -1026,8 +981,7 @@ void KateSearchBar::setSearchPattern(const QString &searchPattern)
 
 QString KateSearchBar::searchPattern() const
 {
-    return (m_powerUi != nullptr) ? m_powerUi->pattern->currentText()
-           : m_incUi->pattern->currentText();
+    return (m_powerUi != nullptr) ? m_powerUi->pattern->currentText() : m_incUi->pattern->currentText();
 }
 
 void KateSearchBar::setSelectionOnly(bool selectionOnly)
@@ -1043,8 +997,7 @@ void KateSearchBar::setSelectionOnly(bool selectionOnly)
 
 bool KateSearchBar::selectionOnly() const
 {
-    return isPower() ? m_powerUi->selectionOnly->isChecked()
-           : false;
+    return isPower() ? m_powerUi->selectionOnly->isChecked() : false;
 }
 
 KTextEditor::SearchOptions KateSearchBar::searchOptions(SearchDirection searchDirection) const
@@ -1076,7 +1029,6 @@ KTextEditor::SearchOptions KateSearchBar::searchOptions(SearchDirection searchDi
         case MODE_PLAIN_TEXT: // FALLTHROUGH
         default:
             break;
-
         }
     }
 
@@ -1152,7 +1104,6 @@ QVector<QString> KateSearchBar::getCapturePatterns(const QString &pattern) const
             default:
                 input++;
                 break;
-
             }
         }
     }
@@ -1175,7 +1126,7 @@ void KateSearchBar::showExtendedContextMenu(bool forPattern, const QPoint &pos)
     switch (m_powerUi->searchMode->currentIndex()) {
     case MODE_REGEX:
         regexMode = true;
-    // FALLTHROUGH
+        // FALLTHROUGH
 
     case MODE_ESCAPE_SEQUENCES:
         extendMenu = true;
@@ -1218,11 +1169,8 @@ void KateSearchBar::showExtendedContextMenu(bool forPattern, const QPoint &pos)
                 const int captureCount = capturePatterns.count();
                 for (int i = 1; i <= 9; i++) {
                     const QString number = QString::number(i);
-                    const QString &captureDetails = (i <= captureCount)
-                                                    ? QLatin1String(" = (") + capturePatterns[i - 1].leftRef(30) + QLatin1Char(')')
-                                                    : QString();
-                    addMenuManager.addEntry(QLatin1String("\\") + number, QString(),
-                                            i18n("Reference") + QLatin1Char(' ') + number + captureDetails);
+                    const QString &captureDetails = (i <= captureCount) ? QLatin1String(" = (") + capturePatterns[i - 1].leftRef(30) + QLatin1Char(')') : QString();
+                    addMenuManager.addEntry(QLatin1String("\\") + number, QString(), i18n("Reference") + QLatin1Char(' ') + number + captureDetails);
                 }
 
                 addMenuManager.addSeparator();
@@ -1470,11 +1418,9 @@ void KateSearchBar::enterPowerMode()
 
         // Hook into line edit context menus
         m_powerUi->pattern->setContextMenuPolicy(Qt::CustomContextMenu);
-        connect(m_powerUi->pattern, SIGNAL(customContextMenuRequested(QPoint)), this,
-                SLOT(onPowerPatternContextMenuRequest(QPoint)));
+        connect(m_powerUi->pattern, SIGNAL(customContextMenuRequested(QPoint)), this, SLOT(onPowerPatternContextMenuRequest(QPoint)));
         m_powerUi->replacement->setContextMenuPolicy(Qt::CustomContextMenu);
-        connect(m_powerUi->replacement, SIGNAL(customContextMenuRequested(QPoint)), this,
-                SLOT(onPowerReplacmentContextMenuRequest(QPoint)));
+        connect(m_powerUi->replacement, SIGNAL(customContextMenuRequested(QPoint)), this, SLOT(onPowerReplacmentContextMenuRequest(QPoint)));
     }
 
     // Focus
@@ -1533,7 +1479,7 @@ void KateSearchBar::enterIncrementalMode()
             delete m_powerUi;
             m_powerUi = nullptr;
             m_layout->removeWidget(m_widget);
-            m_widget->deleteLater(); //deleteLater, because it's not a good idea too delete the widget and there for the button triggering this slot
+            m_widget->deleteLater(); // deleteLater, because it's not a good idea too delete the widget and there for the button triggering this slot
         }
 
         // Add incremental widget
@@ -1542,9 +1488,9 @@ void KateSearchBar::enterIncrementalMode()
         m_incUi->setupUi(m_widget);
         m_layout->addWidget(m_widget);
 
-//         new QShortcut(KStandardShortcut::paste().primary(), m_incUi->pattern, SLOT(paste()), 0, Qt::WidgetWithChildrenShortcut);
-//         if (!KStandardShortcut::paste().alternate().isEmpty())
-//             new QShortcut(KStandardShortcut::paste().alternate(), m_incUi->pattern, SLOT(paste()), 0, Qt::WidgetWithChildrenShortcut);
+        //         new QShortcut(KStandardShortcut::paste().primary(), m_incUi->pattern, SLOT(paste()), 0, Qt::WidgetWithChildrenShortcut);
+        //         if (!KStandardShortcut::paste().alternate().isEmpty())
+        //             new QShortcut(KStandardShortcut::paste().alternate(), m_incUi->pattern, SLOT(paste()), 0, Qt::WidgetWithChildrenShortcut);
 
         // Icons
         // Gnome does not seem to have all icons we want, so we use fall-back icons for those that are missing.
@@ -1616,10 +1562,10 @@ void KateSearchBar::enterIncrementalMode()
 bool KateSearchBar::clearHighlights()
 {
     // Remove ScrollBarMarks
-    KTextEditor::MarkInterface* iface = qobject_cast<KTextEditor::MarkInterface*>(m_view->document());
+    KTextEditor::MarkInterface *iface = qobject_cast<KTextEditor::MarkInterface *>(m_view->document());
     if (iface) {
-        const QHash<int, KTextEditor::Mark*> marks = iface->marks();
-        QHashIterator<int, KTextEditor::Mark*> i(marks);
+        const QHash<int, KTextEditor::Mark *> marks = iface->marks();
+        QHashIterator<int, KTextEditor::Mark *> i(marks);
         while (i.hasNext()) {
             i.next();
             if (i.value()->type & KTextEditor::MarkInterface::SearchMatch) {
@@ -1738,4 +1684,3 @@ void KateSearchBar::slotReadWriteChanged()
     m_powerUi->replaceNext->setEnabled(m_view->doc()->isReadWrite() && isPatternValid());
     m_powerUi->replaceAll->setEnabled(m_view->doc()->isReadWrite() && isPatternValid());
 }
-
