@@ -1,24 +1,25 @@
-/* This file is part of the KDE libraries
-   Copyright (C) 2011 Dominik Haumann <dhaumann@kde.org>
-   Copyright (C) 2009-2010 Bernhard Beschow <bbeschow@cs.tu-berlin.de>
-   Copyright (C) 2002 John Firebaugh <jfirebaugh@kde.org>
-   Copyright (C) 2001 Christoph Cullmann <cullmann@kde.org>
-   Copyright (C) 2001 Joseph Wenninger <jowenn@kde.org>
+/*  SPDX-License-Identifier: LGPL-2.0-or-later
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
+    Copyright (C) 2011 Dominik Haumann <dhaumann@kde.org>
+    Copyright (C) 2009-2010 Bernhard Beschow <bbeschow@cs.tu-berlin.de>
+    Copyright (C) 2002 John Firebaugh <jfirebaugh@kde.org>
+    Copyright (C) 2001 Christoph Cullmann <cullmann@kde.org>
+    Copyright (C) 2001 Joseph Wenninger <jowenn@kde.org>
 
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
+    This library is free software; you can redistribute it and/or
+    modify it under the terms of the GNU Library General Public
+    License as published by the Free Software Foundation; either
+    version 2 of the License, or (at your option) any later version.
 
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+    This library is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+    Library General Public License for more details.
+
+    You should have received a copy of the GNU Library General Public License
+    along with this library; see the file COPYING.LIB.  If not, write to
+    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+    Boston, MA 02110-1301, USA.
 */
 
 #ifndef kate_undo_h
@@ -26,11 +27,14 @@
 
 #include <QList>
 
-#include <ktexteditor/range.h>
 #include <QBitArray>
+#include <ktexteditor/range.h>
 
 class KateUndoManager;
-namespace KTextEditor { class DocumentPrivate; }
+namespace KTextEditor
+{
+class DocumentPrivate;
+}
 
 namespace KTextEditor
 {
@@ -58,16 +62,7 @@ public:
     /**
      * Types for undo items
      */
-    enum UndoType {
-        editInsertText,
-        editRemoveText,
-        editWrapLine,
-        editUnWrapLine,
-        editInsertLine,
-        editRemoveLine,
-        editMarkLineAutoWrapped,
-        editInvalid
-    };
+    enum UndoType { editInsertText, editRemoveText, editWrapLine, editUnWrapLine, editInsertLine, editRemoveLine, editMarkLineAutoWrapped, editInvalid };
 
 public:
     /**
@@ -122,16 +117,7 @@ private:
     // Line modification system
     //
 public:
-    enum ModificationFlag {
-        UndoLine1Modified = 1,
-        UndoLine2Modified = 2,
-        UndoLine1Saved = 4,
-        UndoLine2Saved = 8,
-        RedoLine1Modified = 16,
-        RedoLine2Modified = 32,
-        RedoLine1Saved = 64,
-        RedoLine2Saved = 128
-    };
+    enum ModificationFlag { UndoLine1Modified = 1, UndoLine2Modified = 2, UndoLine1Saved = 4, UndoLine2Saved = 8, RedoLine1Modified = 16, RedoLine2Modified = 32, RedoLine1Saved = 64, RedoLine2Saved = 128 };
 
     inline void setFlag(ModificationFlag flag)
     {
@@ -266,7 +252,8 @@ public:
         : KateUndo(document)
         , m_line(line)
         , m_autowrapped(autowrapped)
-    {}
+    {
+    }
 
     /**
      * @copydoc KateUndo::undo()
@@ -448,6 +435,9 @@ public:
      */
     ~KateUndoGroup();
 
+    KateUndoGroup(const KateUndoGroup &) = delete;
+    KateUndoGroup &operator=(const KateUndoGroup &) = delete;
+
 public:
     /**
      * Undo the contained undo items
@@ -569,4 +559,3 @@ private:
 };
 
 #endif
-
