@@ -1,40 +1,40 @@
-/*  This file is part of the KDE libraries and the Kate part.
- *
- *  Copyright (C) 2003-2005 Anders Lund <anders@alweb.dk>
- *  Copyright (C) 2001-2010 Christoph Cullmann <cullmann@kde.org>
- *  Copyright (C) 2001 Charles Samuels <charles@kde.org>
- *
- *  This library is free software; you can redistribute it and/or
- *  modify it under the terms of the GNU Library General Public
- *  License as published by the Free Software Foundation; either
- *  version 2 of the License, or (at your option) any later version.
- *
- *  This library is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- *  Library General Public License for more details.
- *
- *  You should have received a copy of the GNU Library General Public License
- *  along with this library; see the file COPYING.LIB.  If not, write to
- *  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- *  Boston, MA 02110-1301, USA.
- */
+/*  SPDX-License-Identifier: LGPL-2.0-or-later
+
+    Copyright (C) 2003-2005 Anders Lund <anders@alweb.dk>
+    Copyright (C) 2001-2010 Christoph Cullmann <cullmann@kde.org>
+    Copyright (C) 2001 Charles Samuels <charles@kde.org>
+
+    This library is free software; you can redistribute it and/or
+    modify it under the terms of the GNU Library General Public
+    License as published by the Free Software Foundation; either
+    version 2 of the License, or (at your option) any later version.
+
+    This library is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+    Library General Public License for more details.
+
+    You should have received a copy of the GNU Library General Public License
+    along with this library; see the file COPYING.LIB.  If not, write to
+    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+    Boston, MA 02110-1301, USA.
+*/
 
 #include "katesedcmd.h"
 
-#include "katedocument.h"
-#include "kateview.h"
-#include "kateglobal.h"
 #include "katecmd.h"
+#include "katedocument.h"
+#include "kateglobal.h"
 #include "katepartdebug.h"
+#include "kateview.h"
 
 #include <KLocalizedString>
 
 #include <QDir>
-#include <QRegExp>
+#include <QRegularExpression>
 #include <QUrl>
 
-KateCommands::SedReplace *KateCommands::SedReplace::m_instance = 0;
+KateCommands::SedReplace *KateCommands::SedReplace::m_instance = nullptr;
 
 static int backslashString(const QString &haystack, const QString &needle, int index)
 {
@@ -47,14 +47,13 @@ static int backslashString(const QString &haystack, const QString &needle, int i
         } else {
             // isn't a slash
             if (!evenCount) {
-                if (haystack.mid(index, searchlen) == needle) {
+                if (haystack.midRef(index, searchlen) == needle) {
                     return index - 1;
                 }
             }
             evenCount = true;
         }
         ++index;
-
     }
 
     return -1;
@@ -78,8 +77,7 @@ static void exchangeAbbrevs(QString &str)
     }
 }
 
-bool KateCommands::SedReplace::exec(class KTextEditor::View *view, const QString &cmd,
-                                    QString &msg, const KTextEditor::Range &r)
+bool KateCommands::SedReplace::exec(class KTextEditor::View *view, const QString &cmd, QString &msg, const KTextEditor::Range &r)
 {
     qCDebug(LOG_KTE) << "SedReplace::execCmd( " << cmd << " )";
     if (r.isValid()) {
@@ -95,7 +93,7 @@ bool KateCommands::SedReplace::exec(class KTextEditor::View *view, const QString
         return false;
     }
 
-    const QString searchParamsString = cmd.mid(cmd.lastIndexOf(delimiter));
+    const QStringRef searchParamsString = cmd.midRef(cmd.lastIndexOf(delimiter));
     const bool noCase = searchParamsString.contains(QLatin1Char('i'));
     const bool repeat = searchParamsString.contains(QLatin1Char('g'));
     const bool interactive = searchParamsString.contains(QLatin1Char('c'));
@@ -129,7 +127,14 @@ bool KateCommands::SedReplace::exec(class KTextEditor::View *view, const QString
     QSharedPointer<InteractiveSedReplacer> interactiveSedReplacer(new InteractiveSedReplacer(doc, find, replace, !noCase, !repeat, startLine, endLine));
 
     if (interactive) {
-        return interactiveSedReplace(kateView, interactiveSedReplacer);
+        const bool hasInitialMatch = interactiveSedReplacer->currentMatch().isValid();
+        if (!hasInitialMatch) {
+            // Can't start an interactive sed replace if there is no initial match!
+            msg = interactiveSedReplacer->finalStatusReportMessage();
+            return false;
+        }
+        interactiveSedReplace(kateView, interactiveSedReplacer);
+        return true;
     }
 
     interactiveSedReplacer->replaceAllRemaining();
@@ -147,42 +152,43 @@ bool KateCommands::SedReplace::interactiveSedReplace(KTextEditor::ViewPrivate *,
 bool KateCommands::SedReplace::parse(const QString &sedReplaceString, QString &destDelim, int &destFindBeginPos, int &destFindEndPos, int &destReplaceBeginPos, int &destReplaceEndPos)
 {
     // valid delimiters are all non-word, non-space characters plus '_'
-    QRegExp delim(QLatin1String("^s\\s*([^\\w\\s]|_)"));
-    if (delim.indexIn(sedReplaceString) < 0) {
+    QRegularExpression delim(QStringLiteral("^s\\s*([^\\w\\s]|_)"));
+    auto match = delim.match(sedReplaceString);
+    if (!match.hasMatch()) {
         return false;
     }
 
-    QString d = delim.cap(1);
+    const QString d = match.captured(1);
     qCDebug(LOG_KTE) << "SedReplace: delimiter is '" << d << "'";
 
-    QRegExp splitter(QStringLiteral("^s\\s*") + d + QLatin1String("((?:[^\\\\\\") + d + QLatin1String("]|\\\\.)*)\\")
-                     + d + QLatin1String("((?:[^\\\\\\") + d + QLatin1String("]|\\\\.)*)(\\") + d + QLatin1String("[igc]{0,3})?$"));
-    if (splitter.indexIn(sedReplaceString) < 0) {
+    QRegularExpression splitter(QStringLiteral("^s\\s*") + d + QLatin1String("((?:[^\\\\\\") + d + QLatin1String("]|\\\\.)*)\\") + d + QLatin1String("((?:[^\\\\\\") + d + QLatin1String("]|\\\\.)*)(\\") + d + QLatin1String("[igc]{0,3})?$"));
+    match = splitter.match(sedReplaceString);
+    if (!match.hasMatch()) {
         return false;
     }
 
-    const QString find = splitter.cap(1);
-    const QString replace = splitter.cap(2);
+    const QString find = match.captured(1);
+    const QString replace = match.captured(2);
 
     destDelim = d;
-    destFindBeginPos = splitter.pos(1);
-    destFindEndPos = splitter.pos(1) + find.length() - 1;
-    destReplaceBeginPos = splitter.pos(2);
-    destReplaceEndPos = splitter.pos(2) + replace.length() - 1;
+    destFindBeginPos = match.capturedStart(1);
+    destFindEndPos = match.capturedStart(1) + find.length() - 1;
+    destReplaceBeginPos = match.capturedStart(2);
+    destReplaceEndPos = match.capturedStart(2) + replace.length() - 1;
 
     return true;
 }
 
 KateCommands::SedReplace::InteractiveSedReplacer::InteractiveSedReplacer(KTextEditor::DocumentPrivate *doc, const QString &findPattern, const QString &replacePattern, bool caseSensitive, bool onlyOnePerLine, int startLine, int endLine)
-    : m_findPattern(findPattern),
-      m_replacePattern(replacePattern),
-      m_onlyOnePerLine(onlyOnePerLine),
-      m_endLine(endLine),
-      m_doc(doc),
-      m_regExpSearch(doc, caseSensitive ? Qt::CaseSensitive : Qt::CaseInsensitive),
-      m_numReplacementsDone(0),
-      m_numLinesTouched(0),
-      m_lastChangedLineNum(-1)
+    : m_findPattern(findPattern)
+    , m_replacePattern(replacePattern)
+    , m_onlyOnePerLine(onlyOnePerLine)
+    , m_endLine(endLine)
+    , m_doc(doc)
+    , m_regExpSearch(doc, caseSensitive ? Qt::CaseSensitive : Qt::CaseInsensitive)
+    , m_numReplacementsDone(0)
+    , m_numLinesTouched(0)
+    , m_lastChangedLineNum(-1)
 {
     m_currentSearchPos = KTextEditor::Cursor(startLine, 0);
 }
@@ -229,8 +235,7 @@ void KateCommands::SedReplace::InteractiveSedReplacer::replaceCurrentMatch()
 
         m_currentSearchPos = KTextEditor::Cursor(currentMatch.start().line(), col);
     } else {
-        m_currentSearchPos = KTextEditor::Cursor(currentMatch.start().line() + replacementText.count(QLatin1Char('\n')),
-                                    replacementText.length() - replacementText.lastIndexOf(QLatin1Char('\n')) - 1);
+        m_currentSearchPos = KTextEditor::Cursor(currentMatch.start().line() + replacementText.count(QLatin1Char('\n')), replacementText.length() - replacementText.lastIndexOf(QLatin1Char('\n')) - 1);
     }
     if (m_onlyOnePerLine) {
         // Drop down to next line.
@@ -265,17 +270,13 @@ QString KateCommands::SedReplace::InteractiveSedReplacer::currentMatchReplacemen
 
 QString KateCommands::SedReplace::InteractiveSedReplacer::finalStatusReportMessage()
 {
-    return i18ncp("%2 is the translation of the next message",
-                  "1 replacement done on %2", "%1 replacements done on %2", m_numReplacementsDone,
-                  i18ncp("substituted into the previous message",
-                         "1 line", "%1 lines", m_numLinesTouched));
-
+    return i18ncp("%2 is the translation of the next message", "1 replacement done on %2", "%1 replacements done on %2", m_numReplacementsDone, i18ncp("substituted into the previous message", "1 line", "%1 lines", m_numLinesTouched));
 }
 
 const QVector<KTextEditor::Range> KateCommands::SedReplace::InteractiveSedReplacer::fullCurrentMatch()
 {
     if (m_currentSearchPos > m_doc->documentEnd()) {
-        return QVector <KTextEditor::Range>();
+        return QVector<KTextEditor::Range>();
     }
 
     return m_regExpSearch.search(m_findPattern, KTextEditor::Range(m_currentSearchPos, m_doc->documentEnd()));
@@ -285,10 +286,9 @@ QString KateCommands::SedReplace::InteractiveSedReplacer::replacementTextForCurr
 {
     const QVector<KTextEditor::Range> captureRanges = fullCurrentMatch();
     QStringList captureTexts;
-    foreach (KTextEditor::Range captureRange, captureRanges) {
+    for (KTextEditor::Range captureRange : captureRanges) {
         captureTexts << m_doc->text(captureRange);
     }
     const QString replacementText = m_regExpSearch.buildReplacement(m_replacePattern, captureTexts, 0);
     return replacementText;
-
 }
